@@ -4,11 +4,8 @@ This module defines descriptor classes for aperture attribute
 validation.
 """
 
-import warnings
-
 from astropy.coordinates import SkyCoord
 import astropy.units as u
-from astropy.utils.exceptions import AstropyDeprecationWarning
 import numpy as np
 
 __all__ = ['ApertureAttribute', 'PixelPositions', 'SkyCoordPositions',
@@ -57,7 +54,7 @@ class PixelPositions(ApertureAttribute):
 
     def __set__(self, instance, value):
         # This is needed for zip to work seamlessly in Python 3
-        # (e.g. positions = zip(xpos, ypos))
+        # (e.g., positions = zip(xpos, ypos))
         if isinstance(value, zip):
             value = tuple(value)
 
@@ -68,12 +65,10 @@ class PixelPositions(ApertureAttribute):
             value = value.value
 
         if value.ndim == 2 and value.shape[1] != 2 and value.shape[0] == 2:
-            warnings.warn('Inputing positions shaped as 2xN is deprecated '
-                          'and will be removed in v0.8.  Positions should be '
-                          'a (x, y) pixel position or a list or array of '
-                          '(x, y) pixel positions, e.g. [(x1, y1), '
-                          '(x2, y2), (x3, y3)].', AstropyDeprecationWarning)
-            value = np.transpose(value)
+            raise ValueError('Input positions must be an (x, y) pixel '
+                             'position or a list or array of (x, y) pixel '
+                             'positions, e.g., [(x1, y1), (x2, y2), '
+                             '(x3, y3)].')
 
         instance.__dict__[self.name] = value
 
@@ -82,7 +77,7 @@ class PixelPositions(ApertureAttribute):
             raise u.UnitsError('{} must be in pixel units'.format(self.name))
 
         if np.any(~np.isfinite(value)):
-            raise ValueError('{} must not contain any non-finite (e.g. NaN '
+            raise ValueError('{} must not contain any non-finite (e.g., NaN '
                              'or inf) positions'.format(self.name))
 
         value = np.atleast_2d(value)
@@ -115,7 +110,7 @@ class Scalar(ApertureAttribute):
 
 class PositiveScalar(ApertureAttribute):
     """
-    Check that value is a stricly positive (>= 0) scalar.
+    Check that value is a strictly positive (> 0) scalar.
     """
 
     def _validate(self, value):
