@@ -190,7 +190,7 @@ class EllipticalAperture(EllipticalMaskMixin, PixelAperture):
     def area(self):
         return math.pi * self.a * self.b
 
-    def _to_patch(self, origin=(0, 0), indices=None, **kwargs):
+    def _to_patch(self, origin=(0, 0), **kwargs):
         """
         Return a `~matplotlib.patches.patch` for the aperture.
 
@@ -200,9 +200,6 @@ class EllipticalAperture(EllipticalMaskMixin, PixelAperture):
             The ``(x, y)`` position of the origin of the displayed
             image.
 
-        indices : int or array of int, optional
-            The indices of the aperture positions to plot.
-
         kwargs : `dict`
             Any keyword arguments accepted by
             `matplotlib.patches.Patch`.
@@ -217,8 +214,8 @@ class EllipticalAperture(EllipticalMaskMixin, PixelAperture):
 
         import matplotlib.patches as mpatches
 
-        xy_positions, patch_kwargs = self._define_patch_params(
-            origin=origin, indices=indices, **kwargs)
+        xy_positions, patch_kwargs = self._define_patch_params(origin=origin,
+                                                               **kwargs)
 
         patches = []
         theta_deg = self.theta * 180. / np.pi
@@ -239,10 +236,10 @@ class EllipticalAperture(EllipticalMaskMixin, PixelAperture):
         Parameters
         ----------
         wcs : WCS object
-            A world coordinate system (WCS) transformation that supports
-            the `astropy shared interface for WCS
-            <https://docs.astropy.org/en/stable/wcs/wcsapi.html>`_ (e.g.
-            `astropy.wcs.WCS`, `gwcs.wcs.WCS`).
+            A world coordinate system (WCS) transformation that
+            supports the `astropy shared interface for WCS
+            <https://docs.astropy.org/en/stable/wcs/wcsapi.html>`_
+            (e.g., `astropy.wcs.WCS`, `gwcs.wcs.WCS`).
 
         Returns
         -------
@@ -279,7 +276,10 @@ class EllipticalAnnulus(EllipticalMaskMixin, PixelAperture):
 
     b_out : float
         The outer semiminor axis of the elliptical annulus in pixels.
-        The inner semiminor axis is calculated as:
+
+    b_in : `None` or float, optional
+        The inner semiminor axis of the elliptical annulus in pixels.
+        If `None`, then the the inner semiminor axis is calculated as:
 
             .. math:: b_{in} = b_{out}
                 \\left(\\frac{a_{in}}{a_{out}}\\right)
@@ -312,14 +312,15 @@ class EllipticalAnnulus(EllipticalMaskMixin, PixelAperture):
     >>> aper = EllipticalAnnulus((pos1, pos2, pos3), 3., 8., 5., theta=np.pi)
     """
 
-    _shape_params = ('a_in', 'a_out', 'b_out', 'theta')
+    _shape_params = ('a_in', 'a_out', 'b_in', 'b_out', 'theta')
     positions = PixelPositions('positions')
     a_in = PositiveScalar('a_in')
     a_out = PositiveScalar('a_out')
+    b_in = PositiveScalar('b_in')
     b_out = PositiveScalar('b_out')
     theta = Scalar('theta')
 
-    def __init__(self, positions, a_in, a_out, b_out, theta=0.):
+    def __init__(self, positions, a_in, a_out, b_out, b_in=None, theta=0.):
         if not a_out > a_in:
             raise ValueError('"a_out" must be greater than "a_in".')
 
@@ -327,7 +328,14 @@ class EllipticalAnnulus(EllipticalMaskMixin, PixelAperture):
         self.a_in = a_in
         self.a_out = a_out
         self.b_out = b_out
-        self.b_in = self.b_out * self.a_in / self.a_out
+
+        if b_in is None:
+            b_in = self.b_out * self.a_in / self.a_out
+        else:
+            if not b_out > b_in:
+                raise ValueError('"b_out" must be greater than "b_in".')
+        self.b_in = b_in
+
         self.theta = theta
 
     @property
@@ -338,7 +346,7 @@ class EllipticalAnnulus(EllipticalMaskMixin, PixelAperture):
     def area(self):
         return math.pi * (self.a_out * self.b_out - self.a_in * self.b_in)
 
-    def _to_patch(self, origin=(0, 0), indices=None, **kwargs):
+    def _to_patch(self, origin=(0, 0), **kwargs):
         """
         Return a `~matplotlib.patches.patch` for the aperture.
 
@@ -348,9 +356,6 @@ class EllipticalAnnulus(EllipticalMaskMixin, PixelAperture):
             The ``(x, y)`` position of the origin of the displayed
             image.
 
-        indices : int or array of int, optional
-            The indices of the aperture positions to plot.
-
         kwargs : `dict`
             Any keyword arguments accepted by
             `matplotlib.patches.Patch`.
@@ -365,8 +370,8 @@ class EllipticalAnnulus(EllipticalMaskMixin, PixelAperture):
 
         import matplotlib.patches as mpatches
 
-        xy_positions, patch_kwargs = self._define_patch_params(
-            origin=origin, indices=indices, **kwargs)
+        xy_positions, patch_kwargs = self._define_patch_params(origin=origin,
+                                                               **kwargs)
 
         patches = []
         theta_deg = self.theta * 180. / np.pi
@@ -391,10 +396,10 @@ class EllipticalAnnulus(EllipticalMaskMixin, PixelAperture):
         Parameters
         ----------
         wcs : WCS object
-            A world coordinate system (WCS) transformation that supports
-            the `astropy shared interface for WCS
-            <https://docs.astropy.org/en/stable/wcs/wcsapi.html>`_ (e.g.
-            `astropy.wcs.WCS`, `gwcs.wcs.WCS`).
+            A world coordinate system (WCS) transformation that
+            supports the `astropy shared interface for WCS
+            <https://docs.astropy.org/en/stable/wcs/wcsapi.html>`_
+            (e.g., `astropy.wcs.WCS`, `gwcs.wcs.WCS`).
 
         Returns
         -------
@@ -449,8 +454,8 @@ class SkyEllipticalAperture(SkyAperture):
 
     def __init__(self, positions, a, b, theta=0.*u.deg):
         if a.unit.physical_type != b.unit.physical_type:
-            raise ValueError("a and b should either both be angles "
-                             "or in pixels")
+            raise ValueError('a and b should either both be angles '
+                             'or in pixels')
 
         self.positions = positions
         self.a = a
@@ -465,10 +470,10 @@ class SkyEllipticalAperture(SkyAperture):
         Parameters
         ----------
         wcs : WCS object
-            A world coordinate system (WCS) transformation that supports
-            the `astropy shared interface for WCS
-            <https://docs.astropy.org/en/stable/wcs/wcsapi.html>`_ (e.g.
-            `astropy.wcs.WCS`, `gwcs.wcs.WCS`).
+            A world coordinate system (WCS) transformation that
+            supports the `astropy shared interface for WCS
+            <https://docs.astropy.org/en/stable/wcs/wcsapi.html>`_
+            (e.g., `astropy.wcs.WCS`, `gwcs.wcs.WCS`).
 
         Returns
         -------
@@ -499,8 +504,11 @@ class SkyEllipticalAnnulus(SkyAperture):
         The outer semimajor axis, either in angular or pixel units.
 
     b_out : scalar `~astropy.units.Quantity`
-        The outer semiminor axis, either in angular or pixel units.  The
-        inner semiminor axis is calculated as:
+        The outer semiminor axis, either in angular or pixel units.
+
+    b_in : `None` or scalar `~astropy.units.Quantity`
+        The inner semiminor axis, either in angular or pixel units.
+        If `None`, then the inner semiminor axis is calculated as:
 
             .. math:: b_{in} = b_{out}
                 \\left(\\frac{a_{in}}{a_{out}}\\right)
@@ -521,27 +529,40 @@ class SkyEllipticalAnnulus(SkyAperture):
     ...                             1.0*u.arcsec)
     """
 
-    _shape_params = ('a_in', 'a_out', 'b_out', 'theta')
+    _shape_params = ('a_in', 'a_out', 'b_in', 'b_out', 'theta')
     positions = SkyCoordPositions('positions')
     a_in = AngleOrPixelScalarQuantity('a_in')
     a_out = AngleOrPixelScalarQuantity('a_out')
+    b_in = AngleOrPixelScalarQuantity('b_in')
     b_out = AngleOrPixelScalarQuantity('b_out')
     theta = AngleScalarQuantity('theta')
 
-    def __init__(self, positions, a_in, a_out, b_out, theta=0.*u.deg):
+    def __init__(self, positions, a_in, a_out, b_out, b_in=None,
+                 theta=0.*u.deg):
         if a_in.unit.physical_type != a_out.unit.physical_type:
-            raise ValueError("a_in and a_out should either both be angles "
-                             "or in pixels")
-
+            raise ValueError('a_in and a_out should either both be angles '
+                             'or in pixels')
         if a_out.unit.physical_type != b_out.unit.physical_type:
-            raise ValueError("a_out and b_out should either both be angles "
-                             "or in pixels")
+            raise ValueError('a_out and b_out should either both be angles '
+                             'or in pixels')
+        if not a_out > a_in:
+            raise ValueError('"a_out" must be greater than "a_in".')
 
         self.positions = positions
         self.a_in = a_in
         self.a_out = a_out
         self.b_out = b_out
-        self.b_in = self.b_out * self.a_in / self.a_out
+
+        if b_in is None:
+            b_in = self.b_out * self.a_in / self.a_out
+        else:
+            if b_in.unit.physical_type != b_out.unit.physical_type:
+                raise ValueError('b_in and b_out should either both be '
+                                 'angles or in pixels')
+            if not b_out > b_in:
+                raise ValueError('"b_out" must be greater than "b_in".')
+        self.b_in = b_in
+
         self.theta = theta
 
     def to_pixel(self, wcs):
@@ -552,10 +573,10 @@ class SkyEllipticalAnnulus(SkyAperture):
         Parameters
         ----------
         wcs : WCS object
-            A world coordinate system (WCS) transformation that supports
-            the `astropy shared interface for WCS
-            <https://docs.astropy.org/en/stable/wcs/wcsapi.html>`_ (e.g.
-            `astropy.wcs.WCS`, `gwcs.wcs.WCS`).
+            A world coordinate system (WCS) transformation that
+            supports the `astropy shared interface for WCS
+            <https://docs.astropy.org/en/stable/wcs/wcsapi.html>`_
+            (e.g., `astropy.wcs.WCS`, `gwcs.wcs.WCS`).
 
         Returns
         -------
