@@ -6,21 +6,15 @@ RMS in an image.
 
 from itertools import product
 
+from astropy.stats import SigmaClip
 from astropy.utils import lazyproperty
-from astropy.utils.decorators import deprecated_renamed_argument
-from astropy.version import version as astropy_version
 import numpy as np
 from numpy.lib.index_tricks import index_exp
 
 from .core import SExtractorBackground, StdBackgroundRMS
 from ..utils import ShepardIDWInterpolator
 
-if astropy_version < '3.1':
-    from astropy.stats import SigmaClip
-    SIGMA_CLIP = SigmaClip(sigma=3.0, iters=10)
-else:
-    from ..extern.sigma_clipping import SigmaClip
-    SIGMA_CLIP = SigmaClip(sigma=3.0, maxiters=10)
+SIGMA_CLIP = SigmaClip(sigma=3.0, maxiters=10)
 
 __all__ = ['BkgZoomInterpolator', 'BkgIDWInterpolator', 'Background2D']
 
@@ -83,7 +77,7 @@ class BkgZoomInterpolator:
 
         if bkg2d_obj.edge_method == 'pad':
             # The mesh is first resized to the larger padded-data size
-            # (i.e. zoom_factor should be an integer) and then cropped
+            # (i.e., zoom_factor should be an integer) and then cropped
             # back to the final data size.
             zoom_factor = (int(bkg2d_obj.nyboxes * bkg2d_obj.box_size[0] /
                                mesh.shape[0]),
@@ -159,10 +153,16 @@ class BkgIDWInterpolator:
         if np.ptp(mesh) == 0:
             return np.zeros_like(bkg2d_obj.data) + np.min(mesh)
 
+        yxpos = np.column_stack([bkg2d_obj._mesh_ypos, bkg2d_obj._mesh_xpos])
         mesh1d = mesh[bkg2d_obj.mesh_yidx, bkg2d_obj.mesh_xidx]
-        interp_func = ShepardIDWInterpolator(bkg2d_obj.yx, mesh1d,
+        interp_func = ShepardIDWInterpolator(yxpos, mesh1d,
                                              leafsize=self.leafsize)
-        data = interp_func(bkg2d_obj.data_coords,
+
+        # the position coordinates used when calling the interpolator
+        ny, nx = bkg2d_obj.data.shape
+        data_coords = np.indices((nx, ny)).T.reshape(nx * ny, 2)[:, [1, 0]]
+
+        data = interp_func(data_coords,
                            n_neighbors=self.n_neighbors, power=self.power,
                            reg=self.reg)
 
@@ -197,9 +197,27 @@ class Background2D:
         keyword for more options.
 
     mask : array_like (bool), optional
+        A boolean mask, with the same shape as ``data``, where a `True`
+        value indicates the corresponding element of ``data`` is
+        masked. Masked data are excluded from calculations. ``mask`` is
+        intended to mask sources or bad pixels. Use ``coverage_mask``
+        to mask blank areas of an image. ``mask`` and ``coverage_mask``
+        differ only in that ``coverage_mask`` is applied to the output
+        background and background RMS maps (see ``fill_value``).
+
+    coverage_mask : array_like (bool), optional
         A boolean mask, with the same shape as ``data``, where a `True`
         value indicates the corresponding element of ``data`` is masked.
-        Masked data are excluded from calculations.
+        ``coverage_mask`` should be `True` where there is no coverage
+        (i.e., no data) for a given pixel (e.g., blank areas in a mosaic
+        image). It should not be used for bad pixels (in that case use
+        ``mask`` instead). ``mask`` and ``coverage_mask`` differ only in
+        that ``coverage_mask`` is applied to the output background and
+        background RMS maps (see ``fill_value``).
+
+    fill_value : float, optional
+        The value used to fill the output background and background RMS
+        maps where the input ``coverage_mask`` is `True`.
 
     exclude_percentile : float in the range of [0, 100], optional
         The percentage of masked pixels in a mesh, used as a threshold
@@ -207,8 +225,8 @@ class Background2D:
         than ``exclude_percentile`` percent of its pixels masked then it
         will be excluded from the low-resolution map.  Masked pixels
         include those from the input ``mask``, those resulting from the
-        data padding (i.e. if ``edge_method='pad'``), and those
-        resulting from any sigma clipping (i.e. if ``sigma_clip`` is
+        data padding (i.e., if ``edge_method='pad'``), and those
+        resulting from any sigma clipping (i.e., if ``sigma_clip`` is
         used).  Setting ``exclude_percentile=0`` will exclude meshes
         that have any masked pixels.  Setting ``exclude_percentile=100``
         will only exclude meshes that are completely masked.  Note that
@@ -287,8 +305,8 @@ class Background2D:
     be a constant image.
     """
 
-    def __init__(self, data, box_size, mask=None,
-                 exclude_percentile=10.0, filter_size=(3, 3),
+    def __init__(self, data, box_size, *, mask=None, coverage_mask=None,
+                 fill_value=0.0, exclude_percentile=10.0, filter_size=(3, 3),
                  filter_threshold=None, edge_method='pad',
                  sigma_clip=SIGMA_CLIP,
                  bkg_estimator=SExtractorBackground(sigma_clip=None),
@@ -308,13 +326,21 @@ class Background2D:
             mask = np.asanyarray(mask)
             if mask.shape != data.shape:
                 raise ValueError('mask and data must have the same shape')
+        if coverage_mask is not None:
+            coverage_mask = np.asanyarray(coverage_mask)
+            if coverage_mask.shape != data.shape:
+                raise ValueError('coverage_mask and data must have the same '
+                                 'shape')
 
         if exclude_percentile < 0 or exclude_percentile > 100:
             raise ValueError('exclude_percentile must be between 0 and 100 '
                              '(inclusive).')
 
         self.data = data
-        self.mask = mask
+        self._mask = mask
+        self.coverage_mask = coverage_mask
+        self.fill_value = fill_value
+        self.mask = self._combine_masks()
         self.exclude_percentile = exclude_percentile
 
         filter_size = np.atleast_1d(filter_size)
@@ -336,7 +362,16 @@ class Background2D:
 
         self._prepare_data()
         self._calc_bkg_bkgrms()
-        self._calc_coordinates()
+
+    def _combine_masks(self):
+        if self._mask is None and self.coverage_mask is None:
+            return None
+        if self._mask is None:
+            return self.coverage_mask
+        elif self.coverage_mask is None:
+            return self._mask
+        else:
+            return np.logical_or(self._mask, self.coverage_mask)
 
     def _pad_data(self, yextra, xextra):
         """
@@ -366,11 +401,7 @@ class Background2D:
         if xextra > 0:
             xpad = self.box_size[1] - xextra
         pad_width = ((0, ypad), (0, xpad))
-
-        # mode must be a string for numpy < 0.11
-        # (see https://github.com/numpy/numpy/issues/7112)
-        mode = str('constant')
-        data = np.pad(self.data, pad_width, mode=mode,
+        data = np.pad(self.data, pad_width, mode='constant',
                       constant_values=[1.e10])
 
         # mask the padded regions
@@ -382,7 +413,7 @@ class Background2D:
 
         # pad the input mask separately (there is no np.ma.pad function)
         if self.mask is not None:
-            mask = np.pad(self.mask, pad_width, mode=mode,
+            mask = np.pad(self.mask, pad_width, mode='constant',
                           constant_values=[True])
             mask = np.logical_or(mask, pad_mask)
         else:
@@ -477,7 +508,10 @@ class Background2D:
 
         if (xextra + yextra) == 0:
             # no resizing of the data is necessary
-            data_ma = np.ma.masked_array(self.data, mask=self.mask)
+            mask = self.mask
+            if mask is None:
+                mask = False
+            data_ma = np.ma.masked_array(self.data, mask=mask)
         else:
             # pad or crop the data
             if self.edge_method == 'pad':
@@ -655,9 +689,9 @@ class Background2D:
         Both meshes are computed at the same time here method because
         the filtering of both depends on the background mesh.
 
-        The ``background_mesh`` and ``background_rms_mesh`` images are
-        equivalent to the low-resolution "MINIBACKGROUND" and
-        "MINIBACK_RMS" background maps in SExtractor, respectively.
+        The ``background_mesh`` and ``background_rms_mesh`` images
+        are equivalent to the low-resolution "MINIBACKGROUND" and
+        "MINIBACK_RMS" background maps in SourceExtractor, respectively.
         """
 
         if self.sigma_clip is not None:
@@ -666,7 +700,7 @@ class Background2D:
             data_sigclip = self._mesh_data
         del self._mesh_data
 
-        # preform mesh rejection on sigma-clipped data (i.e. for any
+        # preform mesh rejection on sigma-clipped data (i.e., for any
         # newly-masked pixels)
         idx = self._select_meshes(data_sigclip)
         self.mesh_idx = self.mesh_idx[idx]  # indices for the output mesh
@@ -700,27 +734,15 @@ class Background2D:
         if not np.array_equal(self.filter_size, [1, 1]):
             self._filter_meshes()
 
-    def _calc_coordinates(self):
-        """
-        Calculate the coordinates to use when calling an interpolator.
+    @lazyproperty
+    def _mesh_ypos(self):
+        return (self.mesh_yidx * self.box_size[0] +
+                (self.box_size[0] - 1) / 2.)
 
-        These are needed for `Background2D` and `BackgroundIDW2D`.
-
-        Regular-grid interpolators require a 2D array of values.  Some
-        require a 2D meshgrid of x and y.  Other require a strictly
-        increasing 1D array of the x and y ranges.
-        """
-
-        # the position coordinates used to initialize an interpolation
-        self.y = (self.mesh_yidx * self.box_size[0] +
-                  (self.box_size[0] - 1) / 2.)
-        self.x = (self.mesh_xidx * self.box_size[1] +
-                  (self.box_size[1] - 1) / 2.)
-        self.yx = np.column_stack([self.y, self.x])
-
-        # the position coordinates used when calling an interpolator
-        nx, ny = self.data.shape
-        self.data_coords = np.array(list(product(range(ny), range(nx))))
+    @lazyproperty
+    def _mesh_xpos(self):
+        return (self.mesh_xidx * self.box_size[1] +
+                (self.box_size[1] - 1) / 2.)
 
     @lazyproperty
     def mesh_nmasked(self):
@@ -764,7 +786,7 @@ class Background2D:
         """
         The median value of the 2D low-resolution background map.
 
-        This is equivalent to the value SExtractor prints to stdout
+        This is equivalent to the value SourceExtractor prints to stdout
         (i.e., "(M+D) Background: <value>").
         """
 
@@ -775,7 +797,7 @@ class Background2D:
         """
         The median value of the low-resolution background RMS map.
 
-        This is equivalent to the value SExtractor prints to stdout
+        This is equivalent to the value SourceExtractor prints to stdout
         (i.e., "(M+D) RMS: <value>").
         """
 
@@ -784,16 +806,19 @@ class Background2D:
     @lazyproperty
     def background(self):
         """A 2D `~numpy.ndarray` containing the background image."""
-
-        return self.interpolator(self.background_mesh, self)
+        bkg = self.interpolator(self.background_mesh, self)
+        if self.coverage_mask is not None:
+            bkg[self.coverage_mask] = self.fill_value
+        return bkg
 
     @lazyproperty
     def background_rms(self):
         """A 2D `~numpy.ndarray` containing the background RMS image."""
+        bkg_rms = self.interpolator(self.background_rms_mesh, self)
+        if self.coverage_mask is not None:
+            bkg_rms[self.coverage_mask] = self.fill_value
+        return bkg_rms
 
-        return self.interpolator(self.background_rms_mesh, self)
-
-    @deprecated_renamed_argument('ax', 'axes', '0.7')
     def plot_meshes(self, axes=None, marker='+', color='blue', outlines=False,
                     **kwargs):
         """
@@ -829,10 +854,11 @@ class Background2D:
         kwargs['color'] = color
         if axes is None:
             axes = plt.gca()
-        axes.scatter(self.x, self.y, marker=marker, color=color)
+        axes.scatter(self._mesh_xpos, self._mesh_ypos, marker=marker,
+                     color=color)
         if outlines:
             from ..aperture import RectangularAperture
-            xy = np.column_stack([self.x, self.y])
-            apers = RectangularAperture(xy, self.box_size[1],
+            xypos = np.column_stack([self._mesh_xpos, self._mesh_ypos])
+            apers = RectangularAperture(xypos, self.box_size[1],
                                         self.box_size[0], 0.)
             apers.plot(axes=axes, **kwargs)
