@@ -6,16 +6,11 @@ RMS in an array of any dimension.
 
 import abc
 
-from astropy.stats import biweight_location, biweight_scale, mad_std
-from astropy.version import version as astropy_version
+from astropy.stats import (biweight_location, biweight_scale, mad_std,
+                           SigmaClip)
 import numpy as np
 
-if astropy_version < '3.1':
-    from astropy.stats import SigmaClip
-    SIGMA_CLIP = SigmaClip(sigma=3.0, iters=10)
-else:
-    from ..extern.sigma_clipping import SigmaClip
-    SIGMA_CLIP = SigmaClip(sigma=3.0, maxiters=10)
+SIGMA_CLIP = SigmaClip(sigma=3.0, maxiters=10)
 
 __all__ = ['BackgroundBase', 'BackgroundRMSBase', 'MeanBackground',
            'MedianBackground', 'ModeEstimatorBackground',
@@ -331,16 +326,13 @@ class MMMBackground(ModeEstimatorBackground):
 class SExtractorBackground(BackgroundBase):
     """
     Class to calculate the background in an array using the
-    SExtractor algorithm.
+    Source Extractor algorithm.
 
     The background is calculated using a mode estimator of the form
-    ``(2.5 * median) - (1.5 * mean)``.
+    ``(2.5 * median) - (1.5 * mean)``. If ``(mean - median) / std >
+    0.3`` then the median is used instead.
 
-    If ``(mean - median) / std > 0.3`` then the median is used instead.
-    Despite what the `SExtractor`_ User's Manual says, this is the
-    method it *always* uses.
-
-    .. _SExtractor: https://www.astromatic.net/software/sextractor
+    .. _SourceExtractor: https://sextractor.readthedocs.io/en/latest/
 
     Parameters
     ----------
