@@ -51,6 +51,22 @@ class TestBackground2D:
         assert b.background_median == 1.0
         assert b.background_rms_median == 0.0
 
+    @pytest.mark.parametrize('interpolator', INTERPOLATORS)
+    def test_background_rect(self, interpolator):
+        """
+        Regression test for interpolators with non-square input data.
+        """
+        data = np.arange(12).reshape(3, 4)
+        rms = np.zeros((3, 4))
+        b = Background2D(data, (1, 1), filter_size=1,
+                         interpolator=interpolator)
+        assert_allclose(b.background, data, atol=0.005)
+        assert_allclose(b.background_rms, rms)
+        assert_allclose(b.background_mesh, data)
+        assert_allclose(b.background_rms_mesh, rms)
+        assert b.background_median == 5.5
+        assert b.background_rms_median == 0.0
+
     @pytest.mark.parametrize('interpolator', INTERPOLATORS)
     def test_background_nonconstant(self, interpolator):
         data = np.copy(DATA)
@@ -82,7 +98,7 @@ class TestBackground2D:
                           bkg_estimator=MeanBackground(), edge_method='crop')
         b2 = Background2D(DATA, (23, 22), filter_size=filter_size,
                           bkg_estimator=MeanBackground(), edge_method='pad')
-        assert_allclose(b1.background, b2.background)
+        assert_allclose(b1.background, b2.background, rtol=2e-6)
         assert_allclose(b1.background_rms, b2.background_rms)
 
     @pytest.mark.parametrize('box_size', ([(25, 25), (23, 22)]))
@@ -98,13 +114,13 @@ class TestBackground2D:
         mask[25:50, 25:50] = True
         b = Background2D(data, box_size, filter_size=(1, 1), mask=mask,
                          bkg_estimator=MeanBackground())
-        assert_allclose(b.background, DATA)
+        assert_allclose(b.background, DATA, rtol=2.e-5)
         assert_allclose(b.background_rms, BKG_RMS)
 
         # test edge crop with
         b2 = Background2D(data, box_size, filter_size=(1, 1), mask=mask,
                           bkg_estimator=MeanBackground(), edge_method='crop')
-        assert_allclose(b2.background, DATA)
+        assert_allclose(b2.background, DATA, rtol=2.e-5)
 
     def test_mask(self):
         data = np.copy(DATA)
@@ -125,6 +141,28 @@ class TestBackground2D:
         assert np.ma.count(b2.background_rms_mesh_ma) < b2.nboxes
         assert np.ma.is_masked(b2.mesh_nmasked)
 
+    @pytest.mark.parametrize('fill_value', [0., np.nan, -1.])
+    def test_coverage_mask(self, fill_value):
+        data = np.copy(DATA)
+        data[:50, :50] = np.nan
+        mask = np.isnan(data)
+        b1 = Background2D(data, (25, 25), filter_size=(1, 1),
+                          coverage_mask=mask, fill_value=fill_value,
+                          bkg_estimator=MeanBackground())
+        assert_equal(b1.background[:50, :50], fill_value)
+        assert_equal(b1.background_rms[:50, :50], fill_value)
+
+        # test combination of masks
+        mask = np.zeros(DATA.shape, dtype=bool)
+        coverage_mask = np.zeros(DATA.shape, dtype=bool)
+        mask[:50, :25] = True
+        coverage_mask[:50, 25:50] = True
+        b2 = Background2D(data, (25, 25), filter_size=(1, 1), mask=mask,
+                          coverage_mask=mask, fill_value=0.0,
+                          bkg_estimator=MeanBackground())
+        assert_equal(b1.background_mesh, b2.background_mesh)
+        assert_equal(b1.background_rms_mesh, b2.background_rms_mesh)
+
     def test_completely_masked(self):
         with pytest.raises(ValueError):
             mask = np.ones(DATA.shape, dtype=bool)
@@ -134,7 +172,7 @@ class TestBackground2D:
         """Test case where padding is added only on one axis."""
 
         b = Background2D(DATA, (25, 22), filter_size=(1, 1))
-        assert_allclose(b.background, DATA)
+        assert_allclose(b.background, DATA, rtol=1e-5)
         assert_allclose(b.background_rms, BKG_RMS)
         assert b.background_median == 1.0
         assert b.background_rms_median == 0.0
@@ -192,6 +230,11 @@ class TestBackground2D:
             Background2D(DATA, (25, 25), filter_size=(1, 1),
                          mask=np.zeros((2, 2)))
 
+    def test_coverage_mask_badshape(self):
+        with pytest.raises(ValueError):
+            Background2D(DATA, (25, 25), filter_size=(1, 1),
+                         coverage_mask=np.zeros((2, 2)))
+
     def test_invalid_edge_method(self):
         with pytest.raises(ValueError):
             Background2D(DATA, (23, 22), filter_size=(1, 1),
