@@ -6,80 +6,22 @@ The module contains tools for centroiding sources.
 import inspect
 import warnings
 
-from astropy.modeling import Fittable2DModel, Parameter
-from astropy.modeling.fitting import LevMarLSQFitter
-from astropy.modeling.models import (CONSTRAINTS_DOC, Const1D, Const2D,
-                                     Gaussian1D, Gaussian2D)
 from astropy.nddata.utils import overlap_slices
 from astropy.utils.exceptions import AstropyUserWarning
 import numpy as np
 
-__all__ = ['GaussianConst2D', 'centroid_com', 'gaussian1d_moments',
-           'fit_2dgaussian', 'centroid_1dg', 'centroid_2dg',
-           'centroid_sources', 'centroid_epsf']
+from ..utils._round import _py2intround
+
+__all__ = ['centroid_com', 'centroid_quadratic', 'centroid_sources',
+           'centroid_epsf']
 
 
-class GaussianConst2D(Fittable2DModel):
-    """
-    A model for a 2D Gaussian plus a constant.
-
-    Parameters
-    ----------
-    constant : float
-        Value of the constant.
-
-    amplitude : float
-        Amplitude of the Gaussian.
-
-    x_mean : float
-        Mean of the Gaussian in x.
-
-    y_mean : float
-        Mean of the Gaussian in y.
-
-    x_stddev : float
-        Standard deviation of the Gaussian in x.
-        ``x_stddev`` and ``y_stddev`` must be specified unless a covariance
-        matrix (``cov_matrix``) is input.
-
-    y_stddev : float
-        Standard deviation of the Gaussian in y.
-        ``x_stddev`` and ``y_stddev`` must be specified unless a covariance
-        matrix (``cov_matrix``) is input.
-
-    theta : float, optional
-        Rotation angle in radians. The rotation angle increases
-        counterclockwise.
-    """
-
-    constant = Parameter(default=1)
-    amplitude = Parameter(default=1)
-    x_mean = Parameter(default=0)
-    y_mean = Parameter(default=0)
-    x_stddev = Parameter(default=1)
-    y_stddev = Parameter(default=1)
-    theta = Parameter(default=0)
-
-    @staticmethod
-    def evaluate(x, y, constant, amplitude, x_mean, y_mean, x_stddev,
-                 y_stddev, theta):
-        """Two dimensional Gaussian plus constant function."""
-
-        model = Const2D(constant)(x, y) + Gaussian2D(amplitude, x_mean,
-                                                     y_mean, x_stddev,
-                                                     y_stddev, theta)(x, y)
-        return model
-
-
-GaussianConst2D.__doc__ += CONSTRAINTS_DOC
-
-
-def centroid_com(data, mask=None, oversampling=1.):
+def centroid_com(data, mask=None, oversampling=1):
     """
     Calculate the centroid of an n-dimensional array as its "center of
     mass" determined from moments.
 
-    Invalid values (e.g. NaNs or infs) in the ``data`` array are
+    Non-finite values (e.g., NaN or inf) in the ``data`` array are
     automatically masked.
 
     Parameters
@@ -91,25 +33,18 @@ def centroid_com(data, mask=None, oversampling=1.):
         A boolean mask, with the same shape as ``data``, where a `True`
         value indicates the corresponding element of ``data`` is masked.
 
-    oversampling : float or tuple of two floats, optional
-        Oversampling factors of pixel indices. If ``oversampling`` is a scalar
-        this is treated as both x and y directions having the same oversampling
-        factor; otherwise it is treated as ``(x_oversamp, y_oversamp)``.
+    oversampling : int or tuple of two int, optional
+        Oversampling factors of pixel indices. If ``oversampling`` is
+        a scalar this is treated as both x and y directions having
+        the same oversampling factor; otherwise it is treated as
+        ``(x_oversamp, y_oversamp)``.
 
     Returns
     -------
     centroid : `~numpy.ndarray`
-        The coordinates of the centroid in pixel order (e.g. ``(x, y)``
+        The coordinates of the centroid in pixel order (e.g., ``(x, y)``
         or ``(x, y, z)``), not numpy axis order.
     """
-
-    oversampling = np.atleast_1d(oversampling)
-    if len(oversampling) == 1:
-        oversampling = np.repeat(oversampling, 2)
-    # as these need to match data we reverse the order to (y, x)
-    oversampling = oversampling[::-1]
-    if np.any(oversampling <= 0):
-        raise ValueError('Oversampling factors must all be positive numbers.')
     data = data.astype(float)
 
     if mask is not None and mask is not np.ma.nomask:
@@ -118,11 +53,19 @@ def centroid_com(data, mask=None, oversampling=1.):
             raise ValueError('data and mask must have the same shape.')
         data[mask] = 0.
 
-    badidx = ~np.isfinite(data)
-    if np.any(badidx):
-        warnings.warn('Input data contains input values (e.g. NaNs or infs), '
-                      'which were automatically masked.', AstropyUserWarning)
-        data[badidx] = 0.
+    oversampling = np.atleast_1d(oversampling)
+    if len(oversampling) == 1:
+        oversampling = np.repeat(oversampling, 2)
+    oversampling = oversampling[::-1]  # reverse to (y, x) order
+    if np.any(oversampling <= 0):
+        raise ValueError('Oversampling factors must all be positive numbers.')
+
+    badmask = ~np.isfinite(data)
+    if np.any(badmask):
+        warnings.warn('Input data contains non-finite values (e.g., NaN or '
+                      'inf) that were automatically masked.',
+                      AstropyUserWarning)
+        data[badmask] = 0.
 
     total = np.sum(data)
     indices = np.ogrid[[slice(0, i) for i in data.shape]]
@@ -132,241 +75,179 @@ def centroid_com(data, mask=None, oversampling=1.):
                      for axis in range(data.ndim)])[::-1]
 
 
-def gaussian1d_moments(data, mask=None):
+def centroid_quadratic(data, xpeak=None, ypeak=None, fit_boxsize=5,
+                       search_boxsize=None, mask=None):
     """
-    Estimate 1D Gaussian parameters from the moments of 1D data.
+    Calculate the centroid of an n-dimensional array by fitting a 2D
+    quadratic polynomial.
 
-    This function can be useful for providing initial parameter values
-    when fitting a 1D Gaussian to the ``data``.
+    A second degree 2D polynomial is fit within a small region of the
+    data defined by ``fit_boxsize`` to calculate the centroid position.
+    The initial center of the fitting box can specified using the
+    ``xpeak`` and ``ypeak`` keywords. If both ``xpeak`` and ``ypeak``
+    are `None`, then the box will be centered at the position of the
+    maximum value in the input ``data``.
+
+    If ``xmax`` and ``ymax`` are specified, the ``search_boxsize``
+    optional keyword can be used to further refine the initial center of
+    the fitting box by searching for the position of the maximum pixel
+    within a box of size ``search_boxsize``.
 
     Parameters
     ----------
-    data : array_like (1D)
-        The 1D array.
+    image_data : numpy.ndarray
+        Image data.
 
-    mask : array_like (1D bool), optional
-        A boolean mask, with the same shape as ``data``, where a `True`
-        value indicates the corresponding element of ``data`` is masked.
-
-    Returns
-    -------
-    amplitude, mean, stddev : float
-        The estimated parameters of a 1D Gaussian.
-    """
-
-    if np.any(~np.isfinite(data)):
-        data = np.ma.masked_invalid(data)
-        warnings.warn('Input data contains input values (e.g. NaNs or infs), '
-                      'which were automatically masked.', AstropyUserWarning)
-    else:
-        data = np.ma.array(data)
-
-    if mask is not None and mask is not np.ma.nomask:
-        mask = np.asanyarray(mask)
-        if data.shape != mask.shape:
-            raise ValueError('data and mask must have the same shape.')
-        data.mask |= mask
-
-    data.fill_value = 0.
-    data = data.filled()
-
-    x = np.arange(data.size)
-    x_mean = np.sum(x * data) / np.sum(data)
-    x_stddev = np.sqrt(abs(np.sum(data * (x - x_mean)**2) / np.sum(data)))
-    amplitude = np.ptp(data)
-
-    return amplitude, x_mean, x_stddev
-
-
-def fit_2dgaussian(data, error=None, mask=None):
-    """
-    Fit a 2D Gaussian plus a constant to a 2D image.
-
-    Invalid values (e.g. NaNs or infs) in the ``data`` or ``error``
-    arrays are automatically masked.  The mask for invalid values
-    represents the combination of the invalid-value masks for the
-    ``data`` and ``error`` arrays.
-
-    Parameters
-    ----------
-    data : array_like
-        The 2D array of the image.
-
-    error : array_like, optional
-        The 2D array of the 1-sigma errors of the input ``data``.
-
-    mask : array_like (bool), optional
-        A boolean mask, with the same shape as ``data``, where a `True`
-        value indicates the corresponding element of ``data`` is masked.
-
-    Returns
-    -------
-    result : A `GaussianConst2D` model instance.
-        The best-fitting Gaussian 2D model.
-    """
-
-    from ..morphology import data_properties  # prevent circular imports
-
-    data = np.ma.asanyarray(data)
-
-    if mask is not None and mask is not np.ma.nomask:
-        mask = np.asanyarray(mask)
-        if data.shape != mask.shape:
-            raise ValueError('data and mask must have the same shape.')
-        data.mask |= mask
-
-    if np.any(~np.isfinite(data)):
-        data = np.ma.masked_invalid(data)
-        warnings.warn('Input data contains input values (e.g. NaNs or infs), '
-                      'which were automatically masked.', AstropyUserWarning)
-
-    if error is not None:
-        error = np.ma.masked_invalid(error)
-        if data.shape != error.shape:
-            raise ValueError('data and error must have the same shape.')
-        data.mask |= error.mask
-        weights = 1.0 / error.clip(min=1.e-30)
-    else:
-        weights = np.ones(data.shape)
-
-    if np.ma.count(data) < 7:
-        raise ValueError('Input data must have a least 7 unmasked values to '
-                         'fit a 2D Gaussian plus a constant.')
-
-    # assign zero weight to masked pixels
-    if data.mask is not np.ma.nomask:
-        weights[data.mask] = 0.
-
-    mask = data.mask
-    data.fill_value = 0.0
-    data = data.filled()
-
-    # Subtract the minimum of the data as a crude background estimate.
-    # This will also make the data values positive, preventing issues with
-    # the moment estimation in data_properties (moments from negative data
-    # values can yield undefined Gaussian parameters, e.g. x/y_stddev).
-    props = data_properties(data - np.min(data), mask=mask)
-
-    init_const = 0.  # subtracted data minimum above
-    init_amplitude = np.ptp(data)
-    g_init = GaussianConst2D(constant=init_const, amplitude=init_amplitude,
-                             x_mean=props.xcentroid.value,
-                             y_mean=props.ycentroid.value,
-                             x_stddev=props.semimajor_axis_sigma.value,
-                             y_stddev=props.semiminor_axis_sigma.value,
-                             theta=props.orientation.value)
-    fitter = LevMarLSQFitter()
-    y, x = np.indices(data.shape)
-    gfit = fitter(g_init, x, y, data, weights=weights)
-
-    return gfit
-
-
-def centroid_1dg(data, error=None, mask=None):
-    """
-    Calculate the centroid of a 2D array by fitting 1D Gaussians to the
-    marginal ``x`` and ``y`` distributions of the array.
-
-    Invalid values (e.g. NaNs or infs) in the ``data`` or ``error``
-    arrays are automatically masked.  The mask for invalid values
-    represents the combination of the invalid-value masks for the
-    ``data`` and ``error`` arrays.
-
-    Parameters
-    ----------
-    data : array_like
-        The 2D data array.
-
-    error : array_like, optional
-        The 2D array of the 1-sigma errors of the input ``data``.
-
-    mask : array_like (bool), optional
+    xpeak, ypeak : float or `None`, optional
+        The initial guess of the position of the centroid. When both
+        ``xpeak`` and ``ypeak`` are `None` then the position of the
+        maximum value in the input ``data`` will be used as the initial
+        guess.
+
+    fit_boxsize : int or tuple of int, optional
+        The size (in pixels) of the box used to define the fitting
+        region. If ``fit_boxsize`` has two elements, they should be in
+        ``(ny, nx)`` order. If ``fit_boxsize`` is a scalar then a square
+        box of size ``fit_boxsize`` will be used.
+
+    search_boxsize: int or tuple of int, optional
+        The size (in pixels) of the box used to search for the maximum
+        pixel value if ``xpeak`` and ``ypeak`` are both `None`. If
+        ``fit_boxsize`` has two elements, they should be in ``(ny, nx)``
+        order. If ``fit_boxsize`` is a scalar then a square box of size
+        ``fit_boxsize`` will be used.  This parameter is ignored when
+        ``xmax`` and ``ymax`` are both `None`.  In that case, the entire
+        array is search for the maximum value.
+
+    mask : bool `~numpy.ndarray`, optional
         A boolean mask, with the same shape as ``data``, where a `True`
         value indicates the corresponding element of ``data`` is masked.
+        Masked data are excluded from calculations.
 
     Returns
     -------
     centroid : `~numpy.ndarray`
         The ``x, y`` coordinates of the centroid.
     """
+    if ((xpeak is None and ypeak is not None)
+            or (xpeak is not None and ypeak is None)):
+        raise ValueError('xpeak and ypeak must both be input or "None"')
 
-    data = np.ma.asanyarray(data)
+    data = np.asanyarray(data, dtype=float)
+    ny, nx = data.shape
 
-    if mask is not None and mask is not np.ma.nomask:
-        mask = np.asanyarray(mask)
+    badmask = ~np.isfinite(data)
+    if np.any(badmask):
+        warnings.warn('Input data contains non-finite values (e.g., NaN or '
+                      'inf) that were automatically masked.',
+                      AstropyUserWarning)
+        data[badmask] = np.nan
+
+    if mask is not None:
         if data.shape != mask.shape:
             raise ValueError('data and mask must have the same shape.')
-        data.mask |= mask
+        data[mask] = np.nan
 
-    if np.any(~np.isfinite(data)):
-        data = np.ma.masked_invalid(data)
-        warnings.warn('Input data contains input values (e.g. NaNs or infs), '
-                      'which were automatically masked.', AstropyUserWarning)
+    fit_boxsize = _process_boxsize(fit_boxsize, data.shape)
 
-    if error is not None:
-        error = np.ma.masked_invalid(error)
-        if data.shape != error.shape:
-            raise ValueError('data and error must have the same shape.')
-        data.mask |= error.mask
+    if np.product(fit_boxsize) < 6:
+        raise ValueError('fit_boxsize is too small.  6 values are required '
+                         'to fit a 2D quadratic polynomial.')
 
-        error.mask = data.mask
-        xy_error = [np.sqrt(np.ma.sum(error**2, axis=i)) for i in [0, 1]]
-        xy_weights = [(1.0 / xy_error[i].clip(min=1.e-30)) for i in [0, 1]]
+    if xpeak is None:  # and ypeak too
+        yidx, xidx = np.unravel_index(np.nanargmax(data), data.shape)
     else:
-        xy_weights = [np.ones(data.shape[i]) for i in [1, 0]]
+        xidx = _py2intround(xpeak)
+        yidx = _py2intround(ypeak)
 
-    # assign zero weight where an entire row or column is masked
-    if np.any(data.mask):
-        bad_idx = [np.all(data.mask, axis=i) for i in [0, 1]]
-        for i in [0, 1]:
-            xy_weights[i][bad_idx[i]] = 0.
+        if search_boxsize is not None:
+            search_boxsize = _process_boxsize(search_boxsize, data.shape)
 
-    xy_data = [np.ma.sum(data, axis=i).data for i in [0, 1]]
+            slc_data, slc_cutout = overlap_slices(data.shape, search_boxsize,
+                                                  (yidx, xidx), mode='trim')
+            cutout = data[slc_data]
+            yidx, xidx = np.unravel_index(np.nanargmax(cutout), cutout.shape)
+            xidx += slc_data[1].start
+            yidx += slc_data[0].start
 
-    constant_init = np.ma.min(data)
-    centroid = []
-    for (data_i, weights_i) in zip(xy_data, xy_weights):
-        params_init = gaussian1d_moments(data_i)
-        g_init = Const1D(constant_init) + Gaussian1D(*params_init)
-        fitter = LevMarLSQFitter()
-        x = np.arange(data_i.size)
-        g_fit = fitter(g_init, x, data_i, weights=weights_i)
-        centroid.append(g_fit.mean_1.value)
+    # if peak is at the edge of the data, return the position of the maximum
+    if xidx == 0 or xidx == nx - 1 or yidx == 0 or yidx == ny - 1:
+        warnings.warn('maximum value is at the edge of the data and its '
+                      'position was returned; no quadratic fit was '
+                      'performed', AstropyUserWarning)
+        return np.array((xidx, yidx), dtype=float)
 
-    return np.array(centroid)
+    # extract the fitting region
+    slc_data, slc_cutout = overlap_slices(data.shape, fit_boxsize,
+                                          (yidx, xidx), mode='trim')
+    xidx0, xidx1 = (slc_data[1].start, slc_data[1].stop)
+    yidx0, yidx1 = (slc_data[0].start, slc_data[0].stop)
+
+    # shift the fitting box if it was clipped by the data edge
+    if (xidx1 - xidx0) < fit_boxsize[1]:
+        if xidx0 == 0:
+            xidx1 = min(nx, xidx0 + fit_boxsize[1])
+        if xidx1 == nx:
+            xidx0 = max(0, xidx1 - fit_boxsize[1])
+    if (yidx1 - yidx0) < fit_boxsize[0]:
+        if yidx0 == 0:
+            yidx1 = min(ny, yidx0 + fit_boxsize[0])
+        if yidx1 == ny:
+            yidx0 = max(0, yidx1 - fit_boxsize[0])
+
+    cutout = data[yidx0:yidx1, xidx0:xidx1].ravel()
+    if np.count_nonzero(~np.isnan(cutout)) < 6:
+        warnings.warn('at least 6 unmasked data points are required to '
+                      'perform a 2D quadratic fit',
+                      AstropyUserWarning)
+        return np.array((np.nan, np.nan))
+
+    # fit a 2D quadratic polynomial to the fitting region
+    xi = np.arange(xidx0, xidx1)
+    yi = np.arange(yidx0, yidx1)
+    x, y = np.meshgrid(xi, yi)
+    x = x.ravel()
+    y = y.ravel()
+    coeff_matrix = np.vstack((np.ones_like(x), x, y, x * y, x * x, y * y)).T
+
+    try:
+        c = np.linalg.lstsq(coeff_matrix, cutout, rcond=None)[0]
+    except np.linalg.LinAlgError:
+        warnings.warn('quadratic fit failed', AstropyUserWarning)
+        return np.array((np.nan, np.nan))
+
+    # analytically find the maximum of the polynomial
+    _, c10, c01, c11, c20, c02 = c
+    det = 4 * c20 * c02 - c11**2
+    if det <= 0 or ((c20 > 0.0 and c02 >= 0.0) or (c20 >= 0.0 and c02 > 0.0)):
+        warnings.warn('quadratic fit does not have a maximum',
+                      AstropyUserWarning)
+        return np.array((np.nan, np.nan))
+
+    xm = (c01 * c11 - 2.0 * c02 * c10) / det
+    ym = (c10 * c11 - 2.0 * c20 * c01) / det
+    if xm > 0.0 and xm < (nx - 1.0) and ym > 0.0 and ym < (ny - 1.0):
+        xycen = np.array((xm, ym), dtype=float)
+    else:
+        warnings.warn('quadratic polynomial maximum value falls outside '
+                      'of the image', AstropyUserWarning)
+        return np.array((np.nan, np.nan))
+
+    return xycen
 
 
-def centroid_2dg(data, error=None, mask=None):
-    """
-    Calculate the centroid of a 2D array by fitting a 2D Gaussian (plus
-    a constant) to the array.
-
-    Invalid values (e.g. NaNs or infs) in the ``data`` or ``error``
-    arrays are automatically masked.  The mask for invalid values
-    represents the combination of the invalid-value masks for the
-    ``data`` and ``error`` arrays.
-
-    Parameters
-    ----------
-    data : array_like
-        The 2D data array.
-
-    error : array_like, optional
-        The 2D array of the 1-sigma errors of the input ``data``.
-
-    mask : array_like (bool), optional
-        A boolean mask, with the same shape as ``data``, where a `True`
-        value indicates the corresponding element of ``data`` is masked.
-
-    Returns
-    -------
-    centroid : `~numpy.ndarray`
-        The ``x, y`` coordinates of the centroid.
-    """
-
-    gfit = fit_2dgaussian(data, error=error, mask=mask)
-
-    return np.array([gfit.x_mean.value, gfit.y_mean.value])
+def _process_boxsize(box_size, data_shape):
+    box_size = np.round(np.atleast_1d(box_size)).astype(int)
+    if len(box_size) == 1:
+        box_size = np.repeat(box_size, 2)
+    if len(box_size) > 2:
+        raise ValueError('box size must contain only 1 or 2 values')
+    if np.any(box_size < 0):
+        raise ValueError('box size must be >= 0')
+    # box_size cannot be larger than the data shape
+    box_size = (min(box_size[0], data_shape[0]),
+                min(box_size[1], data_shape[1]))
+    return box_size
 
 
 def centroid_sources(data, xpos, ypos, box_size=11, footprint=None,
@@ -390,19 +271,21 @@ def centroid_sources(data, xpos, ypos, box_size=11, footprint=None,
         calculate the centroid.
 
     box_size : int or array-like of int, optional
-        The size of the cutout image along each axis.  If ``box_size``
+        The size of the cutout image along each axis. If ``box_size``
         is a number, then a square cutout of ``box_size`` will be
-        created.  If ``box_size`` has two elements, they should be in
-        ``(ny, nx)`` order.
+        created. If ``box_size`` has two elements, they should be in
+        ``(ny, nx)`` order. Either ``box_size`` or ``footprint`` must be
+        defined. If they are both defined, then ``footprint`` overrides
+        ``box_size``.
 
     footprint : `~numpy.ndarray` of bools, optional
         A 2D boolean array where `True` values describe the local
-        footprint region to cutout.  ``footprint`` can be used to create
+        footprint region to cutout. ``footprint`` can be used to create
         a non-rectangular cutout image, in which case the input ``xpos``
         and ``ypos`` represent the center of the minimal bounding box
-        for the input ``footprint``.  ``box_size=(n, m)`` is equivalent
-        to ``footprint=np.ones((n, m))``.  Either ``box_size`` or
-        ``footprint`` must be defined.  If they are both defined, then
+        for the input ``footprint``. ``box_size=(n, m)`` is equivalent
+        to ``footprint=np.ones((n, m))``. Either ``box_size`` or
+        ``footprint`` must be defined. If they are both defined, then
         ``footprint`` overrides ``box_size``.
 
     mask : array_like, bool, optional
@@ -416,20 +299,18 @@ def centroid_sources(data, xpos, ypos, box_size=11, footprint=None,
         be used only if supported by the input ``centroid_func``.
 
     centroid_func : callable, optional
-        A callable object (e.g. function or class) that is used to
-        calculate the centroid of a 2D array.  The ``centroid_func``
+        A callable object (e.g., function or class) that is used to
+        calculate the centroid of a 2D array. The ``centroid_func``
         must accept a 2D `~numpy.ndarray`, have a ``mask`` keyword and
-        optionally an ``error`` keyword.  The callable object must
-        return a tuple of two 1D `~numpy.ndarray`\\s, representing the x
-        and y centroids.  The default is
-        `~photutils.centroids.centroid_com`.
+        optionally an ``error`` keyword. The callable object must return
+        a tuple of two 1D `~numpy.ndarray`, representing the x and y
+        centroids. The default is `~photutils.centroids.centroid_com`.
 
     Returns
     -------
     xcentroid, ycentroid : `~numpy.ndarray`
         The ``x`` and ``y`` pixel position(s) of the centroids.
     """
-
     xpos = np.atleast_1d(xpos)
     ypos = np.atleast_1d(ypos)
     if xpos.ndim != 1:
@@ -473,7 +354,7 @@ def centroid_sources(data, xpos, ypos, box_size=11, footprint=None,
             mask_cutout = mask[slices_large]
 
         footprint_mask = ~footprint
-        # trim footprint mask if partial overlap on the data
+        # trim footprint mask if it has only partial overlap on the data
         footprint_mask = footprint_mask[slices_small]
 
         if mask_cutout is None:
@@ -497,14 +378,14 @@ def centroid_sources(data, xpos, ypos, box_size=11, footprint=None,
 
 def centroid_epsf(data, mask=None, oversampling=4, shift_val=0.5):
     """
-    Calculates centering shift of data using pixel symmetry, as
-    described by Anderson and King (2000; PASP 112, 1360) in their
-    ePSF-fitting algorithm.
+    Calculate centering shift of data using pixel symmetry, as described
+    by Anderson and King (2000; PASP 112, 1360) in their ePSF-fitting
+    algorithm.
 
     Calculate the shift of a 2-dimensional symmetric image based on the
     asymmetry between f(x, N) and f(x, -N), along with the differential
-    df/dy(x, shift_val) and df/dy(x, -shift_val). Invalid values (e.g.
-    NaNs or infs) in the ``data`` array are automatically masked.
+    df/dy(x, shift_val) and df/dy(x, -shift_val). Non-finite values
+    (e.g., NaN or inf) in the ``data`` array are automatically masked.
 
     Parameters
     ----------
@@ -513,28 +394,20 @@ def centroid_epsf(data, mask=None, oversampling=4, shift_val=0.5):
     mask : array_like (bool), optional
         A boolean mask, with the same shape as ``data``, where a `True`
         value indicates the corresponding element of ``data`` is masked.
-    oversampling : float or tuple of two floats, optional
+    oversampling : int or tuple of two int, optional
         Oversampling factors of pixel indices. If ``oversampling`` is a
         scalar this is treated as both x and y directions having the
         same oversampling factor.  Otherwise it is treated as
         ``(x_oversamp, y_oversamp)``.
     shift_val : float, optional
         The undersampled value at which to compute the shifts. Default
-        is half a pixel. If supplied, must be a strictly positive
-        number.
+        is half a pixel. It must be a strictly positive number.
 
     Returns
     -------
     centroid : tuple of floats
         The (x, y) coordinates of the centroid in pixel order.
     """
-
-    oversampling = np.atleast_1d(oversampling)
-    if len(oversampling) == 1:
-        oversampling = np.repeat(oversampling, 2)
-    if np.any(oversampling <= 0):
-        raise ValueError('Oversampling factors must all be positive numbers.')
-
     data = data.astype(float)
 
     if mask is not None and mask is not np.ma.nomask:
@@ -543,6 +416,12 @@ def centroid_epsf(data, mask=None, oversampling=4, shift_val=0.5):
             raise ValueError('data and mask must have the same shape.')
         data[mask] = 0.
 
+    oversampling = np.atleast_1d(oversampling)
+    if len(oversampling) == 1:
+        oversampling = np.repeat(oversampling, 2)
+    if np.any(oversampling <= 0):
+        raise ValueError('Oversampling factors must all be positive numbers.')
+
     if shift_val <= 0:
         raise ValueError('shift_val must be a positive number.')
 
@@ -555,15 +434,17 @@ def centroid_epsf(data, mask=None, oversampling=4, shift_val=0.5):
     x_shiftidx = np.around((shift_val * oversampling[0])).astype(int)
     y_shiftidx = np.around((shift_val * oversampling[1])).astype(int)
 
-    badidx = ~np.isfinite([data[y, x]
-                           for x in [xidx_0, xidx_0+x_shiftidx,
-                                     xidx_0+x_shiftidx-1, xidx_0+x_shiftidx+1]
-                           for y in [yidx_0, yidx_0+y_shiftidx,
-                                     yidx_0+y_shiftidx-1,
-                                     yidx_0+y_shiftidx+1]])
-    if np.any(badidx):
-        raise ValueError('One or more centroiding pixels is set to a bad '
-                         'value, e.g., NaN or inf.')
+    badmask = ~np.isfinite([data[y, x]
+                            for x in [xidx_0, xidx_0 + x_shiftidx,
+                                      xidx_0 + x_shiftidx - 1,
+                                      xidx_0 + x_shiftidx + 1]
+                            for y in [yidx_0, yidx_0 + y_shiftidx,
+                                      yidx_0 + y_shiftidx - 1,
+                                      yidx_0 + y_shiftidx + 1]])
+
+    if np.any(badmask):
+        raise ValueError('One or more centroiding pixels is set to a '
+                         'non-finite value, e.g., NaN or inf.')
 
     # In Anderson & King (2000) notation this is psi_E(0.5, 0.0) and
     # values used to compute derivatives.
