@@ -6,6 +6,3 @@ This subpackage provides low-level geometry functions.
 from .circular_overlap import *  # noqa
 from .elliptical_overlap import *  # noqa
 from .rectangular_overlap import *  # noqa
-
-__all__ = ['circular_overlap_grid', 'elliptical_overlap_grid',
-           'rectangular_overlap_grid']
