@@ -25,8 +25,8 @@ class Ellipse:
 
     The isophotes in the image are measured using an iterative method
     described by `Jedrzejewski (1987; MNRAS  226, 747)
-    <http://adsabs.harvard.edu/abs/1987MNRAS.226..747J>`_.  See the
-    **Notes** section below for details about the algorithm.
+    <https://ui.adsabs.harvard.edu/abs/1987MNRAS.226..747J/abstract>`_.
+    See the **Notes** section below for details about the algorithm.
 
     Parameters
     ----------
@@ -54,10 +54,10 @@ class Ellipse:
     -----
     The image is measured using an iterative method described by
     `Jedrzejewski (1987; MNRAS  226, 747)
-    <http://adsabs.harvard.edu/abs/1987MNRAS.226..747J>`_.  Each
-    isophote is fitted at a pre-defined, fixed semimajor axis length.
-    The algorithm starts from a first-guess elliptical isophote defined
-    by approximate values for the (x, y) center coordinates,
+    <https://ui.adsabs.harvard.edu/abs/1987MNRAS.226..747J/abstract>`_.
+    Each isophote is fitted at a pre-defined, fixed semimajor axis
+    length.  The algorithm starts from a first-guess elliptical isophote
+    defined by approximate values for the (x, y) center coordinates,
     ellipticity, and position angle.  Using these values, the image is
     sampled along an elliptical path, producing a 1-dimensional function
     that describes the dependence of intensity (pixel value) with angle
@@ -121,7 +121,7 @@ class Ellipse:
     after the first and second harmonics are subtracted from the raw
     data.  For more details, see the error analysis in `Busko (1996;
     ASPC 101, 139)
-    <http://adsabs.harvard.edu/abs/1996ASPC..101..139B>`_.
+    <https://ui.adsabs.harvard.edu/abs/1996ASPC..101..139B/abstract>`_.
 
     After fitting the ellipse that corresponds to a given value of the
     semimajor axis (by the process described above), the axis length is
@@ -157,8 +157,8 @@ class Ellipse:
     to reflect the solution of the object centerer algorithm.
 
     In some cases the object centerer algorithm may fail, even though
-    there is enough signal-to-noise to start a fit (e.g. in objects with
-    very high ellipticity).  In those cases the sensitivity of the
+    there is enough signal-to-noise to start a fit (e.g., in objects
+    with very high ellipticity). In those cases the sensitivity of the
     algorithm can be decreased by decreasing the value of the object
     centerer threshold parameter. The centerer works by looking to where
     a quantity akin to a signal-to-noise ratio is maximized within the
@@ -291,14 +291,14 @@ class Ellipse:
             ratio.  It specifies the maximum acceptable relative error
             in the local radial intensity gradient.  `Busko (1996; ASPC
             101, 139)
-            <http://adsabs.harvard.edu/abs/1996ASPC..101..139B>`_ showed
-            that the fitting precision relates to that relative error.
-            The usual behavior of the gradient relative error is to
-            increase with semimajor axis, being larger in outer, fainter
-            regions of a galaxy image.  In the current implementation,
-            the ``maxgerr`` criterion is triggered only when two
-            consecutive isophotes exceed the value specified by the
-            parameter. This prevents premature stopping caused by
+            <https://ui.adsabs.harvard.edu/abs/1996ASPC..101..139B/abstract>`_
+            showed that the fitting precision relates to that relative
+            error.  The usual behavior of the gradient relative error is
+            to increase with semimajor axis, being larger in outer,
+            fainter regions of a galaxy image.  In the current
+            implementation, the ``maxgerr`` criterion is triggered only
+            when two consecutive isophotes exceed the value specified by
+            the parameter. This prevents premature stopping caused by
             contamination such as stars and HII regions.
 
             A number of actions may happen when the gradient error
@@ -462,6 +462,12 @@ class Ellipse:
             if isophote.stop_code < 0:
                 self._fix_last_isophote(isophote_list, 0)
 
+            # but if we get an error from the scipy fitter, bail out
+            # immediately. This usually happens at very small radii
+            # when the number of data points is too small.
+            if isophote.stop_code == 3:
+                break
+
             # reset variable from the actual list, since the last
             # `isophote` instance may no longer be OK.
             isophote = isophote_list[-1]
