@@ -83,14 +83,14 @@ class EllipseFitter:
             ratio.  It specifies the maximum acceptable relative error
             in the local radial intensity gradient.  `Busko (1996; ASPC
             101, 139)
-            <http://adsabs.harvard.edu/abs/1996ASPC..101..139B>`_ showed
-            that the fitting precision relates to that relative error.
-            The usual behavior of the gradient relative error is to
-            increase with semimajor axis, being larger in outer, fainter
-            regions of a galaxy image.  In the current implementation,
-            the ``maxgerr`` criterion is triggered only when two
-            consecutive isophotes exceed the value specified by the
-            parameter. This prevents premature stopping caused by
+            <https://ui.adsabs.harvard.edu/abs/1996ASPC..101..139B/abstract>`_
+            showed that the fitting precision relates to that relative
+            error.  The usual behavior of the gradient relative error is
+            to increase with semimajor axis, being larger in outer,
+            fainter regions of a galaxy image.  In the current
+            implementation, the ``maxgerr`` criterion is triggered only
+            when two consecutive isophotes exceed the value specified by
+            the parameter. This prevents premature stopping caused by
             contamination such as stars and HII regions.
 
             A number of actions may happen when the gradient error
@@ -153,6 +153,16 @@ class EllipseFitter:
             # values[2] = 1-d array with intensity
             values = sample.extract()
 
+            # We have to check for a zero-length condition here, and bail out
+            # in case it is detected. The scipy fitter won't raise an exception
+            # for zero-length input arrays, but just prints an "INFO" message.
+            # This may result in an infinite loop.
+            if len(values[2]) < 1:
+                s = str(sample.geometry.sma)
+                log.warning("Too small sample to warrant a fit. SMA is " + s)
+                sample.geometry.fix = fixed_parameters
+                return Isophote(sample, i + 1, False, 3)
+
             # Fit harmonic coefficients. Failure in fitting is
             # a fatal error; terminate immediately with sample
             # marked as invalid.
@@ -167,7 +177,8 @@ class EllipseFitter:
             # Mask out coefficients that control fixed ellipse parameters.
             free_coeffs = ma.masked_array(coeffs[1:], mask=fixed_parameters)
 
-            # Largest non-masked harmonic in absolute value drives the correction.
+            # Largest non-masked harmonic in absolute value drives the
+            # correction.
             largest_harmonic_index = np.argmax(np.abs(free_coeffs))
             largest_harmonic = free_coeffs[largest_harmonic_index]
 
