@@ -38,7 +38,7 @@ def build_ellipse_model(shape, isolist, fill=0., high_harmonics=False):
         no contribution from any isophote, it will be assigned this
         value.  The default is 0.
     high_harmonics : bool, optional
-        Whether to add the higher-order harmonics (i.e. ``a3``, ``b3``,
+        Whether to add the higher-order harmonics (i.e., ``a3``, ``b3``,
         ``a4``, and ``b4``; see `~photutils.isophote.Isophote` for
         details) to the result.
 
@@ -120,7 +120,7 @@ def build_ellipse_model(shape, isolist, fill=0., high_harmonics=False):
                 harm = (a3_array[index] * np.sin(3.*phi) +
                         b3_array[index] * np.cos(3.*phi) +
                         a4_array[index] * np.sin(4.*phi) +
-                        b4_array[index] * np.cos(4.*phi) / 4.)
+                        b4_array[index] * np.cos(4.*phi)) / 4.
 
             # get image coordinates of (r, phi) pixel
             x = r * np.cos(phi + pa) + x0
@@ -128,7 +128,6 @@ def build_ellipse_model(shape, isolist, fill=0., high_harmonics=False):
             i = int(x)
             j = int(y)
 
-            # if outside image boundaries, ignore.
             if (i > 0 and i < shape[1] - 1 and j > 0 and j < shape[0] - 1):
                 # get fractional deviations relative to target array
                 fx = x - float(i)
@@ -149,7 +148,10 @@ def build_ellipse_model(shape, isolist, fill=0., high_harmonics=False):
 
                 # step towards next pixel on ellipse
                 phi = max((phi + 0.75 / r), geometry._phi_min)
-                r = geometry.radius(phi)
+                r = max(geometry.radius(phi), 0.5)
+            # if outside image boundaries, ignore.
+            else:
+                break
 
     # zero weight values must be set to 1.
     weight[np.where(weight <= 0.)] = 1.
