@@ -12,13 +12,14 @@ import warnings
 from astropy.modeling.fitting import LevMarLSQFitter
 from astropy.nddata.utils import (overlap_slices, PartialOverlapError,
                                   NoOverlapError)
+from astropy.stats import SigmaClip
 from astropy.utils.exceptions import AstropyUserWarning
 import numpy as np
 
 from .epsf_stars import EPSFStar, EPSFStars, LinkedEPSFStar
 from .models import EPSFModel
-from ..centroids import centroid_epsf
-from ..extern.sigma_clipping import SigmaClip
+from ..centroids import centroid_com, centroid_epsf
+from ..utils._round import _py2intround
 
 try:
     import bottleneck  # pylint: disable=W0611
@@ -41,7 +42,7 @@ class EPSFFitter:
     fit_boxsize : int, tuple of int, or `None`, optional
         The size (in pixels) of the box centered on the star to be used
         for ePSF fitting.  This allows using only a small number of
-        central pixels of the star (i.e. where the star is brightest)
+        central pixels of the star (i.e., where the star is brightest)
         for fitting.  If ``fit_boxsize`` is a scalar then a square box
         of size ``fit_boxsize`` will be used.  If ``fit_boxsize`` has
         two elements, they should be in ``(ny, nx)`` order.  The size
@@ -187,7 +188,7 @@ class EPSFFitter:
         # Define positions in the undersampled grid. The fitter will
         # evaluate on the defined interpolation grid, currently in the
         # range [0, len(undersampled grid)].
-        yy, xx = np.indices(data.shape, dtype=np.float)
+        yy, xx = np.indices(data.shape, dtype=float)
         xx = xx + x0 - star.cutout_center[0]
         yy = yy + y0 - star.cutout_center[1]
 
@@ -234,9 +235,10 @@ class EPSFBuilder:
     Class to build an effective PSF (ePSF).
 
     See `Anderson and King (2000; PASP 112, 1360)
-    <http://adsabs.harvard.edu/abs/2000PASP..112.1360A>`_ and
-    `Anderson (2016), ISR WFC3 2016-12
-    <www.stsci.edu/hst/wfc3/documents/ISRs/WFC3-2016-12.pdf>`_ for details.
+    <https://ui.adsabs.harvard.edu/abs/2000PASP..112.1360A/abstract>`_
+    and `Anderson (2016), ISR WFC3 2016-12
+    <https://www.stsci.edu/files/live/sites/www/files/home/hst/instrumentation/wfc3/documentation/instrument-science-reports-isrs/_documents/2016/WFC3-2016-12.pdf>`_
+    for details.
 
     Parameters
     ----------
@@ -264,10 +266,10 @@ class EPSFBuilder:
         no smoothing will be performed.
 
     recentering_func : callable, optional
-        A callable object (e.g. function or class) that is used to
-        calculate the centroid of a 2D array.  The callable must accept
+        A callable object (e.g., function or class) that is used to
+        calculate the centroid of a 2D array. The callable must accept
         a 2D `~numpy.ndarray`, have a ``mask`` keyword and optionally
-        ``error`` and ``oversampling`` keywords.  The callable object
+        ``error`` and ``oversampling`` keywords. The callable object
         must return a tuple of two 1D `~numpy.ndarray` variables,
         representing the x and y centroids.
 
@@ -305,22 +307,27 @@ class EPSFBuilder:
             iterations will stop if the centers of all the stars change by
             less than ``center_accuracy`` pixels between iterations.  All
             stars must meet this condition for the loop to exit.
+
+    flux_residual_sigclip : `~astropy.stats.SigmaClip` object, optional
+        A `~astropy.stats.SigmaClip` object used to determine which pixels
+        are ignored based on the star sampling flux residuals, when
+        computing the average residual of ePSF grid points in each iteration
+        step.
     """
 
     def __init__(self, oversampling=4., shape=None,
-                 smoothing_kernel='quartic', recentering_func=centroid_epsf,
+                 smoothing_kernel='quartic', recentering_func=centroid_com,
                  recentering_maxiters=20, fitter=EPSFFitter(), maxiters=10,
                  progress_bar=True, norm_radius=5.5, shift_val=0.5,
-                 recentering_boxsize=(5, 5), center_accuracy=1.0e-3):
-        flux_residual_sigclip = SigmaClip(sigma=3, cenfunc='median', maxiters=10)  # TODO: replace with kwarg in 8.0
+                 recentering_boxsize=(5, 5), center_accuracy=1.0e-3,
+                 flux_residual_sigclip=SigmaClip(sigma=3, cenfunc='median',
+                                                 maxiters=10)):
 
         if oversampling is None:
             raise ValueError("'oversampling' must be specified.")
         oversampling = np.atleast_1d(oversampling).astype(int)
         if len(oversampling) == 1:
             oversampling = np.repeat(oversampling, 2)
-        if np.any(oversampling % 2 != 0):
-            raise ValueError('Oversampling factor must be a multiple of two.')
         if np.any(oversampling <= 0.0):
             raise ValueError('oversampling must be a positive number.')
         self._norm_radius = norm_radius
@@ -414,16 +421,17 @@ class EPSFBuilder:
             # Stars class should have odd-sized dimensions, and thus we
             # get the oversampled shape as oversampling * len + 1; if
             # len=25, then newlen=101, for example.
-            x_shape = np.int(np.ceil(stars._max_shape[0]) * oversampling[0]
-                             + 1)
-            y_shape = np.int(np.ceil(stars._max_shape[1]) * oversampling[1]
-                             + 1)
+            x_shape = (np.ceil(stars._max_shape[0]) * oversampling[0] +
+                       1).astype(int)
+            y_shape = (np.ceil(stars._max_shape[1]) * oversampling[1] +
+                       1).astype(int)
+
             shape = np.array((y_shape, x_shape))
 
         # verify odd sizes of shape
         shape = [(i + 1) if i % 2 == 0 else i for i in shape]
 
-        data = np.zeros(shape, dtype=np.float)
+        data = np.zeros(shape, dtype=float)
 
         # ePSF origin should be in the undersampled pixel units, not the
         # oversampled grid units. The middle, fractional (as we wish for
@@ -585,7 +593,7 @@ class EPSFBuilder:
 
         return convolve(epsf_data, kernel)
 
-    def _recenter_epsf(self, epsf, centroid_func=centroid_epsf,
+    def _recenter_epsf(self, epsf, centroid_func=centroid_com,
                        box_size=(5, 5), maxiters=20, center_accuracy=1.0e-4):
         """
         Calculate the center of the ePSF data and shift the data so the
@@ -597,12 +605,12 @@ class EPSFBuilder:
             The ePSF model.
 
         centroid_func : callable, optional
-            A callable object (e.g. function or class) that is used to
-            calculate the centroid of a 2D array.  The callable must
-            accept a 2D `~numpy.ndarray`, have a ``mask`` keyword and
-            optionally an ``error`` keyword.  The callable object must
-            return a tuple of two 1D `~numpy.ndarray` variables, representing
-            the x and y centroids.
+            A callable object (e.g., function or class) that is used
+            to calculate the centroid of a 2D array. The callable must
+            accept a 2D `~numpy.ndarray`, have a ``mask`` keyword
+            and optionally an ``error`` keyword. The callable object
+            must return a tuple of two 1D `~numpy.ndarray` variables,
+            representing the x and y centroids.
         box_size : float or tuple of two floats, optional
             The size (in pixels) of the box used to calculate the
             centroid of the ePSF during each build iteration.  If a
@@ -631,7 +639,7 @@ class EPSFBuilder:
 
         xcenter, ycenter = epsf.origin
 
-        y, x = np.indices(epsf._data.shape, dtype=np.float)
+        y, x = np.indices(epsf._data.shape, dtype=float)
         x /= epsf.oversampling[0]
         y /= epsf.oversampling[1]
 
@@ -865,23 +873,6 @@ class EPSFBuilder:
         return epsf, stars
 
 
-def _py2intround(a):
-    """
-    Round the input to the nearest integer.
-
-    If two integers are equally close, rounding is done away from 0.
-    """
-
-    data = np.asanyarray(a)
-    value = np.where(data >= 0, np.floor(data + 0.5),
-                     np.ceil(data - 0.5)).astype(int)
-
-    if not hasattr(a, '__iter__'):
-        value = np.asscalar(value)
-
-    return value
-
-
 def _interpolate_missing_data(data, mask, method='cubic'):
     """
     Interpolate missing data as identified by the ``mask`` keyword.
