@@ -6,7 +6,7 @@ This module provides classes to perform PSF-fitting photometry.
 import warnings
 
 from astropy.modeling.fitting import LevMarLSQFitter
-from astropy.nddata.utils import overlap_slices
+from astropy.nddata.utils import overlap_slices, NoOverlapError
 from astropy.stats import SigmaClip, gaussian_sigma_to_fwhm
 from astropy.table import Column, Table, hstack, vstack
 from astropy.utils.exceptions import AstropyUserWarning
@@ -50,7 +50,8 @@ class BasicPSFPhotometry:
         ``y_0``, and ``group_id``. The column ``group_id`` should cotain
         integers starting from ``1`` that indicate which group a given
         source belongs to. See, e.g., `~photutils.psf.DAOGroup`.
-    bkg_estimator : callable, instance of any `~photutils.background.BackgroundBase` subclass, or None
+    bkg_estimator : callable, instance of any \
+            `~photutils.background.BackgroundBase` subclass, or None
         ``bkg_estimator`` should be able to compute either a scalar
         background or a 2D background of a given 2D image. See, e.g.,
         `~photutils.background.MedianBackground`.  If None, no
@@ -66,14 +67,15 @@ class BasicPSFPhotometry:
         ``flux``.  `~photutils.psf.prepare_psf_model` can be used to
         prepare any 2D model to match this assumption.
     fitshape : int or length-2 array-like
-        Rectangular shape around the center of a star which will be used
-        to collect the data to do the fitting. Can be an integer to be
-        the same along both axes. E.g., 5 is the same as (5, 5), which
-        means to fit only at the following relative pixel positions:
-        [-2, -1, 0, 1, 2].  Each element of ``fitshape`` must be an odd
-        number.
-    finder : callable or instance of any `~photutils.detection.StarFinderBase` subclasses or None
-        ``finder`` should be able to identify stars, i.e. compute a
+        Rectangular shape around the center of a star which will be
+        used to collect the data to do the fitting. Can be an integer
+        to be the same along both axes. For example, 5 is the same as
+        (5, 5), which means to fit only at the following relative pixel
+        positions: [-2, -1, 0, 1, 2]. Each element of ``fitshape`` must
+        be an odd number.
+    finder : callable or instance of any \
+            `~photutils.detection.StarFinderBase` subclasses or None
+        ``finder`` should be able to identify stars, i.e., compute a
         rough estimate of the centroids, in a given 2D image.
         ``finder`` receives as input a 2D image and returns an
         `~astropy.table.Table` object which contains columns with names:
@@ -93,9 +95,13 @@ class BasicPSFPhotometry:
         estimates for the fluxes of sources.  ``aperture_radius`` must
         be set if initial flux guesses are not input to the photometry
         class via the ``init_guesses`` keyword.  For tabular PSF models
-        (e.g. an `EPSFModel`), you must input the ``aperture_radius``
+        (e.g., an `EPSFModel`), you must input the ``aperture_radius``
         keyword.  For analytical PSF models, alternatively you may
         define a FWHM attribute on your input psf_model.
+    extra_output_cols : list of str, optional
+        List of additional columns for parameters derived by any of the
+        intermediate fitting steps (e.g., ``finder``), such as roundness
+        or sharpness.
 
     Notes
     -----
@@ -108,18 +114,20 @@ class BasicPSFPhotometry:
     If there are problems with fitting large groups, change the
     parameters of the grouping algorithm to reduce the number of sources
     in each group or input a ``star_groups`` table that only includes
-    the groups that are relevant (e.g. manually remove all entries that
+    the groups that are relevant (e.g., manually remove all entries that
     coincide with artifacts).
 
     References
     ----------
     [1] Stetson, Astronomical Society of the Pacific, Publications,
         (ISSN 0004-6280), vol. 99, March 1987, p. 191-222.
-        Available at: http://adsabs.harvard.edu/abs/1987PASP...99..191S
+        Available at:
+        https://ui.adsabs.harvard.edu/abs/1987PASP...99..191S/abstract
     """
 
     def __init__(self, group_maker, bkg_estimator, psf_model, fitshape,
-                 finder=None, fitter=LevMarLSQFitter(), aperture_radius=None):
+                 finder=None, fitter=LevMarLSQFitter(), aperture_radius=None,
+                 extra_output_cols=None):
         self.group_maker = group_maker
         self.bkg_estimator = bkg_estimator
         self.psf_model = psf_model
@@ -130,6 +138,7 @@ class BasicPSFPhotometry:
         self._pars_to_set = None
         self._pars_to_output = None
         self._residual_image = None
+        self._extra_output_cols = extra_output_cols
 
     @property
     def fitshape(self):
@@ -177,7 +186,8 @@ class BasicPSFPhotometry:
 
         Returns
         -------
-        residual_image : 2D array-like, `~astropy.io.fits.ImageHDU`, `~astropy.io.fits.HDUList`
+        residual_image : 2D array-like, `~astropy.io.fits.ImageHDU`, \
+            `~astropy.io.fits.HDUList`
         """
 
         return self._residual_image
@@ -207,7 +217,8 @@ class BasicPSFPhotometry:
 
         Parameters
         ----------
-        image : 2D array-like, `~astropy.io.fits.ImageHDU`, `~astropy.io.fits.HDUList`
+        image : 2D array-like, `~astropy.io.fits.ImageHDU`, \
+                `~astropy.io.fits.HDUList`
             Image to perform photometry.
         init_guesses: `~astropy.table.Table`
             Table which contains the initial guesses (estimates) for the
@@ -218,7 +229,10 @@ class BasicPSFPhotometry:
             used to estimate initial values for the fluxes. Additional
             columns of the form '<parametername>_0' will be used to set
             the initial guess for any parameters of the ``psf_model``
-            model that are not fixed.
+            model that are not fixed. If ``init_guesses`` supplied with
+            ``extra_output_cols`` the initial values are used; if the columns
+            specified in ``extra_output_cols`` are not given in
+            ``init_guesses`` then NaNs will be returned.
 
         Returns
         -------
@@ -247,7 +261,7 @@ class BasicPSFPhotometry:
             if init_guesses is None:
                 raise ValueError('aperture_radius was not input and could '
                                  'not be determined by the input psf_model '
-                                 '(e.g. an EPSFModel).  For tabular PSF '
+                                 '(e.g., an EPSFModel).  For tabular PSF '
                                  'models, you must input the aperture_radius '
                                  'keyword.  For analytical PSF models, you '
                                  'must either input the aperture_radius '
@@ -261,7 +275,7 @@ class BasicPSFPhotometry:
                                  'cannot be calculated because '
                                  'aperture_radius must was not input and '
                                  'could not be determined by the input '
-                                 'psf_model (e.g. an EPSFModel).  For '
+                                 'psf_model (e.g., an EPSFModel).  For '
                                  'analytical PSF models, you must either '
                                  'input the aperture_radius keyword or '
                                  'define a fwhm or sigma attribute on your '
@@ -284,6 +298,15 @@ class BasicPSFPhotometry:
 
                 init_guesses['flux_0'] = aperture_photometry(
                     image, apertures)['aperture_sum']
+
+            # if extra_output_cols have been given, check whether init_guesses
+            # was supplied with extra_output_cols pre-attached and populate
+            # columns not given with NaNs
+            if self._extra_output_cols is not None:
+                for col_name in self._extra_output_cols:
+                    if col_name not in init_guesses.colnames:
+                        init_guesses[col_name] = np.full(len(init_guesses),
+                                                         np.nan)
         else:
             if self.finder is None:
                 raise ValueError('Finder cannot be None if init_guesses are '
@@ -298,11 +321,19 @@ class BasicPSFPhotometry:
                 sources['aperture_flux'] = aperture_photometry(
                     image, apertures)['aperture_sum']
 
+                # init_guesses should be the initial 3 required parameters --
+                # x, y, flux -- and then concatentated with any additional
+                # sources, if there are any
                 init_guesses = Table(names=['x_0', 'y_0', 'flux_0'],
                                      data=[sources['xcentroid'],
                                            sources['ycentroid'],
                                            sources['aperture_flux']])
 
+                # Currently only needed for the finder, as group_maker and
+                # nstar return the original Table with new columns, unlike
+                # finder
+                self._get_additional_columns(sources, init_guesses)
+
         self._define_fit_param_names()
         for p0, param in self._pars_to_set.items():
             if p0 not in init_guesses.colnames:
@@ -375,15 +406,12 @@ class BasicPSFPhotometry:
                                                    len(star_groups.groups[n]))
             result_tab = vstack([result_tab, param_table])
 
-            if 'param_cov' in self.fitter.fit_info.keys():
+            param_cov = self.fitter.fit_info.get('param_cov', None)
+            if param_cov is not None:
                 unc_tab = vstack([unc_tab,
                                   self._get_uncertainties(
                                       len(star_groups.groups[n]))])
-            try:
-                from astropy.nddata.utils import NoOverlapError
-            except ImportError:
-                raise ImportError("astropy 1.1 or greater is required in "
-                                  "order to use this class.")
+
             # do not subtract if the fitting did not go well
             try:
                 image = subtract_psf(image, self.psf_model, param_table,
@@ -391,11 +419,23 @@ class BasicPSFPhotometry:
             except NoOverlapError:
                 pass
 
-        if 'param_cov' in self.fitter.fit_info.keys():
+        if param_cov is not None:
             result_tab = hstack([result_tab, unc_tab])
 
         return result_tab, image
 
+    def _get_additional_columns(self, in_table, out_table):
+        """
+        Function to parse additional columns from ``in_table`` and add them to
+        ``out_table``.
+
+        """
+
+        if self._extra_output_cols is not None:
+            for col_name in self._extra_output_cols:
+                if col_name in in_table.colnames:
+                    out_table[col_name] = in_table[col_name]
+
     def _define_fit_param_names(self):
         """
         Convenience function to define mappings between the names of the
@@ -445,15 +485,13 @@ class BasicPSFPhotometry:
                 unc_tab.add_column(Column(name=param_name + "_unc",
                                           data=np.empty(star_group_size)))
 
-        if 'param_cov' in self.fitter.fit_info.keys():
-            if self.fitter.fit_info['param_cov'] is not None:
-                k = 0
-                n_fit_params = len(unc_tab.colnames)
-                for i in range(star_group_size):
-                    unc_tab[i] = np.sqrt(np.diag(
-                                          self.fitter.fit_info['param_cov'])
-                                         )[k: k + n_fit_params]
-                    k = k + n_fit_params
+        k = 0
+        n_fit_params = len(unc_tab.colnames)
+        param_cov = self.fitter.fit_info.get('param_cov', None)
+        for i in range(star_group_size):
+            unc_tab[i] = np.sqrt(np.diag(param_cov))[k: k + n_fit_params]
+            k = k + n_fit_params
+
         return unc_tab
 
     def _model_params2table(self, fit_model, star_group_size):
@@ -490,7 +528,8 @@ class BasicPSFPhotometry:
                                                            '_' + str(i)).value
         else:
             for param_tab_name, param_name in self._pars_to_output.items():
-                param_tab[param_tab_name] = getattr(fit_model, param_name).value
+                param_tab[param_tab_name] = getattr(fit_model,
+                                                    param_name).value
 
         return param_tab
 
@@ -516,7 +555,8 @@ class IterativelySubtractedPSFPhotometry(BasicPSFPhotometry):
         ``y_0``, and ``group_id``. The column ``group_id`` should cotain
         integers starting from ``1`` that indicate which group a given
         source belongs to. See, e.g., `~photutils.psf.DAOGroup`.
-    bkg_estimator : callable, instance of any `~photutils.background.BackgroundBase` subclass, or None
+    bkg_estimator : callable, instance of any \
+            `~photutils.background.BackgroundBase` subclass, or None
         ``bkg_estimator`` should be able to compute either a scalar
         background or a 2D background of a given 2D image. See, e.g.,
         `~photutils.background.MedianBackground`.  If None, no
@@ -532,14 +572,15 @@ class IterativelySubtractedPSFPhotometry(BasicPSFPhotometry):
         ``flux``.  `~photutils.psf.prepare_psf_model` can be used to
         prepare any 2D model to match this assumption.
     fitshape : int or length-2 array-like
-        Rectangular shape around the center of a star which will be used
-        to collect the data to do the fitting. Can be an integer to be
-        the same along both axes. E.g., 5 is the same as (5, 5), which
-        means to fit only at the following relative pixel positions:
-        [-2, -1, 0, 1, 2].  Each element of ``fitshape`` must be an odd
-        number.
-    finder : callable or instance of any `~photutils.detection.StarFinderBase` subclasses
-        ``finder`` should be able to identify stars, i.e. compute a
+        Rectangular shape around the center of a star which will be
+        used to collect the data to do the fitting. Can be an integer
+        to be the same along both axes. For example, 5 is the same as
+        (5, 5), which means to fit only at the following relative pixel
+        positions: [-2, -1, 0, 1, 2]. Each element of ``fitshape`` must
+        be an odd number.
+    finder : callable or instance of any \
+            `~photutils.detection.StarFinderBase` subclasses
+        ``finder`` should be able to identify stars, i.e., compute a
         rough estimate of the centroids, in a given 2D image.
         ``finder`` receives as input a 2D image and returns an
         `~astropy.table.Table` object which contains columns with names:
@@ -563,28 +604,33 @@ class IterativelySubtractedPSFPhotometry(BasicPSFPhotometry):
         stars remain.  Note that in this case it is *possible* that the
         loop will never end if the PSF has structure that causes
         subtraction to create new sources infinitely.
+    extra_output_cols : list of str, optional
+        List of additional columns for parameters derived by any of the
+        intermediate fitting steps (e.g., ``finder``), such as roundness
+        or sharpness.
 
     Notes
     -----
     If there are problems with fitting large groups, change the
     parameters of the grouping algorithm to reduce the number of sources
     in each group or input a ``star_groups`` table that only includes
-    the groups that are relevant (e.g. manually remove all entries that
+    the groups that are relevant (e.g., manually remove all entries that
     coincide with artifacts).
 
     References
     ----------
     [1] Stetson, Astronomical Society of the Pacific, Publications,
         (ISSN 0004-6280), vol. 99, March 1987, p. 191-222.
-        Available at: http://adsabs.harvard.edu/abs/1987PASP...99..191S
+        Available at:
+        https://ui.adsabs.harvard.edu/abs/1987PASP...99..191S/abstract
     """
 
     def __init__(self, group_maker, bkg_estimator, psf_model, fitshape,
                  finder, fitter=LevMarLSQFitter(), niters=3,
-                 aperture_radius=None):
+                 aperture_radius=None, extra_output_cols=None):
 
         super().__init__(group_maker, bkg_estimator, psf_model, fitshape,
-                         finder, fitter, aperture_radius)
+                         finder, fitter, aperture_radius, extra_output_cols)
         self.niters = niters
 
     @property
@@ -636,7 +682,8 @@ class IterativelySubtractedPSFPhotometry(BasicPSFPhotometry):
 
         Parameters
         ----------
-        image : 2D array-like, `~astropy.io.fits.ImageHDU`, `~astropy.io.fits.HDUList`
+        image : 2D array-like, `~astropy.io.fits.ImageHDU`, \
+                `~astropy.io.fits.HDUList`
             Image to perform photometry.
         init_guesses: `~astropy.table.Table`
             Table which contains the initial guesses (estimates) for the
@@ -647,7 +694,10 @@ class IterativelySubtractedPSFPhotometry(BasicPSFPhotometry):
             used to estimate initial values for the fluxes. Additional
             columns of the form '<parametername>_0' will be used to set
             the initial guess for any parameters of the ``psf_model``
-            model that are not fixed.
+            model that are not fixed. If ``init_guesses`` supplied with
+            ``extra_output_cols`` the initial values are used; if the columns
+            specified in ``extra_output_cols`` are not given in
+            ``init_guesses`` then NaNs will be returned.
 
         Returns
         -------
@@ -663,13 +713,11 @@ class IterativelySubtractedPSFPhotometry(BasicPSFPhotometry):
 
         if init_guesses is not None:
             table = super().do_photometry(image, init_guesses)
-            table['iter_detected'] = np.ones(table['x_fit'].shape,
-                                             dtype=np.int32)
+            table['iter_detected'] = np.ones(table['x_fit'].shape, dtype=int)
 
             # n_start = 2 because it starts in the second iteration
             # since the first iteration is above
-            output_table = self._do_photometry(init_guesses.colnames,
-                                               n_start=2)
+            output_table = self._do_photometry(n_start=2)
             output_table = vstack([table, output_table])
         else:
             if self.bkg_estimator is not None:
@@ -684,20 +732,16 @@ class IterativelySubtractedPSFPhotometry(BasicPSFPhotometry):
                     self.aperture_radius = (self.psf_model.sigma.value *
                                             gaussian_sigma_to_fwhm)
 
-            output_table = self._do_photometry(['x_0', 'y_0', 'flux_0'])
+            output_table = self._do_photometry()
         return output_table
 
-    def _do_photometry(self, param_tab, n_start=1):
+    def _do_photometry(self, n_start=1):
         """
         Helper function which performs the iterations of the photometry
         process.
 
         Parameters
         ----------
-        param_names :  list
-            Names of the columns which represent the initial guesses.
-            For example, ['x_0', 'y_0', 'flux_0'], for intial guesses on
-            the center positions and the flux.
         n_start : int
             Integer representing the start index of the iteration.  It
             is 1 if init_guesses are None, and 2 otherwise.
@@ -734,6 +778,7 @@ class IterativelySubtractedPSFPhotometry(BasicPSFPhotometry):
                                    data=[sources['id'], sources['xcentroid'],
                                          sources['ycentroid'],
                                          sources['aperture_flux']])
+            self._get_additional_columns(sources, init_guess_tab)
 
             for param_tab_name, param_name in self._pars_to_set.items():
                 if param_tab_name not in (['x_0', 'y_0', 'flux_0']):
@@ -750,8 +795,8 @@ class IterativelySubtractedPSFPhotometry(BasicPSFPhotometry):
             star_groups = star_groups.group_by('group_id')
             table = hstack([star_groups, table])
 
-            table['iter_detected'] = n*np.ones(table['x_fit'].shape,
-                                               dtype=np.int32)
+            table['iter_detected'] = n * np.ones(table['x_fit'].shape,
+                                                 dtype=int)
 
             output_table = vstack([output_table, table])
 
@@ -811,12 +856,12 @@ class DAOPhotPSFPhotometry(IterativelySubtractedPSFPhotometry):
         ``flux``.  `~photutils.psf.prepare_psf_model` can be used to
         prepare any 2D model to match this assumption.
     fitshape : int or length-2 array-like
-        Rectangular shape around the center of a star which will be used
-        to collect the data to do the fitting. Can be an integer to be
-        the same along both axes. E.g., 5 is the same as (5, 5), which
-        means to fit only at the following relative pixel positions:
-        [-2, -1, 0, 1, 2].  Each element of ``fitshape`` must be an odd
-        number.
+        Rectangular shape around the center of a star which will be
+        used to collect the data to do the fitting. Can be an integer
+        to be the same along both axes. For example, 5 is the same as
+        (5, 5), which means to fit only at the following relative pixel
+        positions: [-2, -1, 0, 1, 2]. Each element of ``fitshape`` must
+        be an odd number.
     sigma : float, optional
         Number of standard deviations used to perform sigma clip with a
         `astropy.stats.SigmaClip` object.
@@ -855,27 +900,32 @@ class DAOPhotPSFPhotometry(IterativelySubtractedPSFPhotometry):
         The radius (in units of pixels) used to compute initial
         estimates for the fluxes of sources. If ``None``, one FWHM will
         be used if it can be determined from the ```psf_model``.
+    extra_output_cols : list of str, optional
+        List of additional columns for parameters derived by any of the
+        intermediate fitting steps (e.g., ``finder``), such as roundness
+        or sharpness.
 
     Notes
     -----
     If there are problems with fitting large groups, change the
     parameters of the grouping algorithm to reduce the number of sources
     in each group or input a ``star_groups`` table that only includes
-    the groups that are relevant (e.g. manually remove all entries that
+    the groups that are relevant (e.g., manually remove all entries that
     coincide with artifacts).
 
     References
     ----------
     [1] Stetson, Astronomical Society of the Pacific, Publications,
         (ISSN 0004-6280), vol. 99, March 1987, p. 191-222.
-        Available at: http://adsabs.harvard.edu/abs/1987PASP...99..191S
+        Available at:
+        https://ui.adsabs.harvard.edu/abs/1987PASP...99..191S/abstract
     """
 
     def __init__(self, crit_separation, threshold, fwhm, psf_model, fitshape,
                  sigma=3., ratio=1.0, theta=0.0, sigma_radius=1.5,
                  sharplo=0.2, sharphi=1.0, roundlo=-1.0, roundhi=1.0,
                  fitter=LevMarLSQFitter(),
-                 niters=3, aperture_radius=None):
+                 niters=3, aperture_radius=None, extra_output_cols=None):
 
         self.crit_separation = crit_separation
         self.threshold = threshold
@@ -900,4 +950,5 @@ class DAOPhotPSFPhotometry(IterativelySubtractedPSFPhotometry):
         super().__init__(group_maker=group_maker, bkg_estimator=bkg_estimator,
                          psf_model=psf_model, fitshape=fitshape,
                          finder=finder, fitter=fitter, niters=niters,
-                         aperture_radius=aperture_radius)
+                         aperture_radius=aperture_radius,
+                         extra_output_cols=extra_output_cols)
