@@ -5,7 +5,7 @@ Tests for the photometry module.
 
 from astropy.convolution.utils import discretize_model
 from astropy.modeling import Fittable2DModel, Parameter
-from astropy.modeling.fitting import LevMarLSQFitter
+from astropy.modeling.fitting import LevMarLSQFitter, SimplexLSQFitter
 from astropy.modeling.models import Gaussian2D, Moffat2D
 from astropy.stats import SigmaClip, gaussian_sigma_to_fwhm
 from astropy.table import Table
@@ -38,9 +38,9 @@ def make_psf_photometry_objs(std=1, sigma_psf=1):
     modified as-needed in specific tests below
     """
 
-    daofind = DAOStarFinder(threshold=5.0*std,
-                            fwhm=sigma_psf*gaussian_sigma_to_fwhm)
-    daogroup = DAOGroup(1.5*sigma_psf*gaussian_sigma_to_fwhm)
+    daofind = DAOStarFinder(threshold=5.0 * std,
+                            fwhm=sigma_psf * gaussian_sigma_to_fwhm)
+    daogroup = DAOGroup(1.5 * sigma_psf * gaussian_sigma_to_fwhm)
     threshold = 5. * std
     fwhm = sigma_psf * gaussian_sigma_to_fwhm
     crit_separation = 1.5 * sigma_psf * gaussian_sigma_to_fwhm
@@ -122,9 +122,9 @@ def test_psf_photometry_niters(sigma_psf, sources):
     # background noise (Poisson)
     image = (make_gaussian_prf_sources_image(img_shape, sources) +
              make_noise_image(img_shape, distribution='poisson', mean=6.,
-                              random_state=1) +
+                              seed=0) +
              make_noise_image(img_shape, distribution='gaussian', mean=0.,
-                              stddev=2., random_state=1))
+                              stddev=2., seed=0))
     cp_image = image.copy()
     sigma_clip = SigmaClip(sigma=3.)
     bkgrms = StdBackgroundRMS(sigma_clip)
@@ -163,9 +163,9 @@ def test_psf_photometry_niters(sigma_psf, sources):
                           (sigma_psfs[1], sources2),
                           # these ensure that the test *fails* if the model
                           # PSFs are the wrong shape
-                          pytest.param(sigma_psfs[0]/1.2, sources1,
+                          pytest.param(sigma_psfs[0] / 1.2, sources1,
                                        marks=pytest.mark.xfail()),
-                          pytest.param(sigma_psfs[1]*1.2, sources2,
+                          pytest.param(sigma_psfs[1] * 1.2, sources2,
                                        marks=pytest.mark.xfail())])
 def test_psf_photometry_oneiter(sigma_psf, sources):
     """
@@ -178,9 +178,9 @@ def test_psf_photometry_oneiter(sigma_psf, sources):
     # background noise (Poisson)
     image = (make_gaussian_prf_sources_image(img_shape, sources) +
              make_noise_image(img_shape, distribution='poisson', mean=6.,
-                              random_state=1) +
+                              seed=0) +
              make_noise_image(img_shape, distribution='gaussian', mean=0.,
-                              stddev=2., random_state=1))
+                              stddev=2., seed=0))
     cp_image = image.copy()
 
     sigma_clip = SigmaClip(sigma=3.)
@@ -314,7 +314,7 @@ def test_finder_positions_warning():
 
     image = (make_gaussian_prf_sources_image((32, 32), sources1) +
              make_noise_image((32, 32), distribution='poisson', mean=6.,
-                              random_state=1))
+                              seed=0))
 
     with catch_warnings(AstropyUserWarning):
         result_tab = basic_phot_obj(image=image, init_guesses=positions)
@@ -336,9 +336,9 @@ def test_aperture_radius():
     # background noise (Poisson)
     image = (make_gaussian_prf_sources_image(img_shape, sources1) +
              make_noise_image(img_shape, distribution='poisson', mean=6.,
-                              random_state=1) +
+                              seed=0) +
              make_noise_image(img_shape, distribution='gaussian', mean=0.,
-                              stddev=2., random_state=1))
+                              stddev=2., seed=0))
 
     basic_phot_obj = make_psf_photometry_objs()[0]
 
@@ -604,6 +604,56 @@ def test_psf_fitting_data_on_edge():
                         rtol=0.05, atol=0.1)
 
 
+@pytest.mark.skipif('not HAS_SCIPY')
+@pytest.mark.parametrize("sigma_psf, sources", [(sigma_psfs[2], sources3)])
+def test_psf_extra_output_cols(sigma_psf, sources):
+    """
+    Test the handling of a non-None extra_output_cols
+    """
+
+    psf_model = IntegratedGaussianPRF(sigma=sigma_psf)
+    tshape = (32, 32)
+    image = (make_gaussian_prf_sources_image(tshape, sources) +
+             make_noise_image(tshape, distribution='poisson', mean=6.,
+                              seed=0) +
+             make_noise_image(tshape, distribution='gaussian', mean=0.,
+                              stddev=2., seed=0))
+
+    init_guess1 = None
+    init_guess2 = Table(names=['x_0', 'y_0', 'sharpness', 'roundness1',
+                               'roundness2'],
+                        data=[[17.4], [16], [0.4], [0], [0]])
+    init_guess3 = Table(names=['x_0', 'y_0'],
+                        data=[[17.4], [16]])
+    init_guess4 = Table(names=['x_0', 'y_0', 'sharpness'],
+                        data=[[17.4], [16], [0.4]])
+    for i, init_guesses in enumerate([init_guess1, init_guess2, init_guess3,
+                                      init_guess4]):
+        dao_phot = DAOPhotPSFPhotometry(crit_separation=8, threshold=40,
+                                        fwhm=4 * np.sqrt(2 * np.log(2)),
+                                        psf_model=psf_model, fitshape=(11, 11),
+                                        extra_output_cols=['sharpness',
+                                                           'roundness1',
+                                                           'roundness2'])
+        phot_results = dao_phot(image, init_guesses=init_guesses)
+        # test that the original required columns are also passed back, as well
+        # as extra_output_cols
+        assert np.all([name in phot_results.colnames for name in
+                       ['x_0', 'y_0']])
+        assert np.all([name in phot_results.colnames for name in
+                       ['sharpness', 'roundness1', 'roundness2']])
+        assert len(phot_results) == 2
+        # checks to verify that half-passing init_guesses results in NaN output
+        # for extra_output_cols not passed as initial guesses
+        if i == 2:  # init_guess3
+            assert(np.all(np.all(np.isnan(phot_results[o])) for o in
+                   ['sharpness', 'roundness1', 'roundness2']))
+        if i == 3:  # init_guess4
+            assert(np.all(np.all(np.isnan(phot_results[o])) for o in
+                   ['roundness1', 'roundness2']))
+            assert(np.all(~np.isnan(phot_results['sharpness'])))
+
+
 @pytest.mark.skipif('not HAS_SCIPY')
 def test_finder_return_none():
     """
@@ -619,13 +669,13 @@ def test_finder_return_none():
             ys, xs = np.where(image == f)
             x = np.mean(xs)
             y = np.mean(ys)
-            table.add_row([int(n+1), x, y, f*9])
+            table.add_row([int(n + 1), x, y, f * 9])
         table.sort(['flux'])
 
         return table
 
     prf = np.zeros((7, 7), float)
-    prf[2:5, 2:5] = 1/9
+    prf[2:5, 2:5] = 1 / 9
     prf = FittableImageModel(prf)
 
     img = np.zeros((50, 50), float)
@@ -633,7 +683,7 @@ def test_finder_return_none():
     y0 = [20, 5, 40]
     f0 = [50, 100, 200]
     for x, y, f in zip(x0, y0, f0):
-        img[y-1:y+2, x-1:x+2] = f/9
+        img[y - 1:y + 2, x - 1:x + 2] = f / 9
 
     intab = Table(data=[[37, 19.6, 34.9], [19.6, 4.5, 40.1], [45, 103, 210]],
                   names=['x_0', 'y_0', 'flux_0'])
@@ -647,3 +697,22 @@ def test_finder_return_none():
 
     results = iter_phot(image=img, init_guesses=intab)
     assert_allclose(results['flux_fit'], f0, rtol=0.05)
+
+
+@pytest.mark.skipif('not HAS_SCIPY')
+def test_psf_photometry_uncertainties():
+    """
+    Test an Astropy fitter that does not return a parameter
+    covariance matrix (param_cov). The output table should not
+    contain flux_unc, x_0_unc, and y_0_unc columns.
+    """
+    psf = IntegratedGaussianPRF(sigma=GAUSSIAN_WIDTH)
+
+    basic_phot = BasicPSFPhotometry(group_maker=DAOGroup(2),
+                                    bkg_estimator=None, psf_model=psf,
+                                    fitter=SimplexLSQFitter(),
+                                    fitshape=7)
+    phot_tbl = basic_phot(image=image, init_guesses=INTAB)
+    columns = ('flux_unc', 'x_0_unc', 'y_0_unc')
+    for column in columns:
+        assert column not in phot_tbl.colnames
