@@ -6,7 +6,8 @@ segment within a segmentation image.
 
 from copy import deepcopy
 
-from astropy.utils import lazyproperty, deprecated
+from astropy.utils import lazyproperty
+from astropy.utils.decorators import deprecated_renamed_argument
 import numpy as np
 
 from ..aperture import BoundingBox
@@ -74,9 +75,9 @@ class Segment:
     def data(self):
         """
         A cutout array of the segment using the minimal bounding box,
-        where pixels outside of the labeled region are set to zero (i.e.
-        neighboring segments within the rectangular cutout array are not
-        shown).
+        where pixels outside of the labeled region are set to zero
+        (i.e., neighboring segments within the rectangular cutout array
+        are not shown).
         """
 
         cutout = np.copy(self._segment_data[self.slices])
@@ -91,7 +92,7 @@ class Segment:
         minimal bounding box.
 
         The mask is `True` for pixels outside of the source segment
-        (i.e. neighboring segments within the rectangular cutout array
+        (i.e., neighboring segments within the rectangular cutout array
         are masked).
         """
 
@@ -120,7 +121,7 @@ class Segment:
         If ``masked_array`` is `False` (default), then the returned
         cutout array is simply a `~numpy.ndarray`.  The returned cutout
         is a view (not a copy) of the input ``data``.  No pixels are
-        altered (e.g. set to zero) within the bounding box.
+        altered (e.g., set to zero) within the bounding box.
 
         If ``masked_array` is `True`, then the returned cutout array is
         a `~numpy.ma.MaskedArray`, where the mask is `True` for pixels
@@ -168,7 +169,7 @@ class SegmentationImage:
         different positive integer values.  A value of zero is reserved
         for the background.  The segmentation image must contain at
         least one non-zero pixel and must not contain any non-finite
-        values (e.g. NaN, inf).
+        values (e.g., NaN, inf).
     """
 
     def __init__(self, data):
@@ -212,7 +213,7 @@ class SegmentationImage:
         This is very useful for plotting the segmentation array.
         """
 
-        return self.make_cmap(background_color='#000000', random_state=1234)
+        return self.make_cmap(background_color='#000000', seed=0)
 
     @staticmethod
     def _get_labels(data):
@@ -280,7 +281,7 @@ class SegmentationImage:
     def data(self, value):
         if np.any(~np.isfinite(value)):
             raise ValueError('data must not contain any non-finite values '
-                             '(e.g. NaN, inf)')
+                             '(e.g., NaN, inf)')
 
         value = np.asarray(value, dtype=int)
         if not np.any(value):
@@ -533,8 +534,8 @@ class SegmentationImage:
             else:
                 raise ValueError('labels {} are invalid'.format(bad_labels))
 
-    @deprecated('0.7', alternative='make_cmap')
-    def cmap(self, background_color='#000000', random_state=None):
+    @deprecated_renamed_argument('random_state', 'seed', '1.0')
+    def make_cmap(self, background_color='#000000', seed=None):
         """
         Define a matplotlib colormap consisting of (random) muted
         colors.
@@ -549,34 +550,11 @@ class SegmentationImage:
             background color (label = 0) when plotting the segmentation
             array.  The default is black ('#000000').
 
-        random_state : int or `~numpy.random.mtrand.RandomState`, optional
-            The pseudo-random number generator state used for random
-            sampling.  Separate function calls with the same
-            ``random_state`` will generate the same colormap.
-        """
-
-        return self.make_cmap(background_color=background_color,
-                              random_state=random_state)  # pragma: no cover
-
-    def make_cmap(self, background_color='#000000', random_state=None):
-        """
-        Define a matplotlib colormap consisting of (random) muted
-        colors.
-
-        This is very useful for plotting the segmentation array.
-
-        Parameters
-        ----------
-        background_color : str or `None`, optional
-            A hex string in the "#rrggbb" format defining the first
-            color in the colormap.  This color will be used as the
-            background color (label = 0) when plotting the segmentation
-            array.  The default is black ('#000000').
-
-        random_state : int or `~numpy.random.mtrand.RandomState`, optional
-            The pseudo-random number generator state used for random
-            sampling.  Separate function calls with the same
-            ``random_state`` will generate the same colormap.
+        seed : int, optional
+            A seed to initialize the `numpy.random.BitGenerator`. If
+            `None`, then fresh, unpredictable entropy will be pulled
+            from the OS.  Separate function calls with the same ``seed``
+            will generate the same colormap.
 
         Returns
         -------
@@ -586,32 +564,13 @@ class SegmentationImage:
 
         from matplotlib import colors
 
-        cmap = make_random_cmap(self.max_label + 1, random_state=random_state)
+        cmap = make_random_cmap(self.max_label + 1, seed=seed)
 
         if background_color is not None:
             cmap.colors[0] = colors.hex2color(background_color)
 
         return cmap
 
-    @deprecated('0.7', alternative='reassign_labels')
-    def relabel(self, labels, new_label):
-        """
-        Reassign one or more label numbers.
-
-        Multiple input ``labels`` will all be reassigned to the same
-        ``new_label`` number.
-
-        Parameters
-        ----------
-        labels : int, array-like (1D, int)
-            The label numbers(s) to reassign.
-
-        new_label : int
-            The reassigned label number.
-        """
-
-        self.reassign_label(labels, new_label)  # pragma: no cover
-
     def reassign_label(self, label, new_label, relabel=False):
         """
         Reassign a label number to a new number.
@@ -766,9 +725,10 @@ class SegmentationImage:
 
         if relabel:
             labels = np.unique(idx[idx != 0])
-            idx2 = np.zeros(max(labels) + 1, dtype=int)
-            idx2[labels] = np.arange(len(labels)) + 1
-            idx = idx2[idx]
+            if not len(labels) == 0:
+                idx2 = np.zeros(max(labels) + 1, dtype=int)
+                idx2[labels] = np.arange(len(labels)) + 1
+                idx = idx2[idx]
 
         data_new = idx[self.data]
         self.__dict__ = {}  # reset all cached properties
