@@ -11,7 +11,7 @@ import numpy as np
 
 from .core import SegmentationImage
 from .detect import _make_binary_structure, _detect_sources
-from ..utils.convolution import _filter_data
+from ..utils._convolution import _filter_data
 from ..utils.exceptions import NoDetectionsWarning
 
 __all__ = ['deblend_sources']
@@ -81,7 +81,7 @@ def deblend_sources(data, segment_img, npixels, filter_kernel=None,
         are grouped into a detected source.  The options are 8 (default)
         or 4.  8-connected pixels touch along their edges or corners.
         4-connected pixels touch along their edges.  For reference,
-        SExtractor uses 8-connected pixels.
+        SourceExtractor uses 8-connected pixels.
 
     relabel : bool
         If `True` (default), then the segmentation image will be
@@ -207,7 +207,7 @@ def _deblend_source(data, segment_img, npixels, nlevels=32, contrast=0.001,
         are grouped into a detected source.  The options are 8 (default)
         or 4.  8-connected pixels touch along their edges or corners.
         4-connected pixels touch along their edges.  For reference,
-        SExtractor uses 8-connected pixels.
+        SourceExtractor uses 8-connected pixels.
 
     Returns
     -------
@@ -219,7 +219,7 @@ def _deblend_source(data, segment_img, npixels, nlevels=32, contrast=0.001,
     """
 
     from scipy.ndimage import label as ndilabel
-    from skimage.morphology import watershed
+    from skimage.segmentation import watershed
 
     if nlevels < 1:
         raise ValueError('nlevels must be >= 1, got "{0}"'.format(nlevels))
