@@ -7,12 +7,11 @@ import warnings
 
 from astropy.convolution import Gaussian2DKernel
 from astropy.stats import gaussian_fwhm_to_sigma
-from astropy.utils.decorators import deprecated_renamed_argument
 import numpy as np
 
 from .core import SegmentationImage
 from ..detection import detect_threshold
-from ..utils.convolution import _filter_data
+from ..utils._convolution import _filter_data
 from ..utils.exceptions import NoDetectionsWarning
 
 __all__ = ['detect_sources', 'make_source_mask']
@@ -30,9 +29,9 @@ def _make_binary_structure(ndim, connectivity):
     connectivity : {4, 8}
         For the case of ``ndim=2``, the type of pixel connectivity used
         in determining how pixels are grouped into a detected source.
-        The options are 4 or 8 (default).  4-connected pixels touch
-        along their edges.  8-connected pixels touch along their edges
-        or corners.  For reference, SExtractor uses 8-connected pixels.
+        The options are 4 or 8 (default). 4-connected pixels touch along
+        their edges. 8-connected pixels touch along their edges or
+        corners. For reference, SourceExtractor uses 8-connected pixels.
 
     Returns
     -------
@@ -99,10 +98,10 @@ def _detect_sources(data, thresholds, npixels, filter_kernel=None,
 
     connectivity : {4, 8}, optional
         The type of pixel connectivity used in determining how pixels
-        are grouped into a detected source.  The options are 4 or 8
-        (default).  4-connected pixels touch along their edges.
-        8-connected pixels touch along their edges or corners.  For
-        reference, SExtractor uses 8-connected pixels.
+        are grouped into a detected source. The options are 4 or
+        8 (default). 4-connected pixels touch along their edges.
+        8-connected pixels touch along their edges or corners. For
+        reference, SourceExtractor uses 8-connected pixels.
 
     mask : array_like of bool, optional
         A boolean mask, with the same shape as the input ``data``, where
@@ -234,10 +233,10 @@ def detect_sources(data, threshold, npixels, filter_kernel=None,
 
     connectivity : {4, 8}, optional
         The type of pixel connectivity used in determining how pixels
-        are grouped into a detected source.  The options are 4 or 8
-        (default).  4-connected pixels touch along their edges.
-        8-connected pixels touch along their edges or corners.  For
-        reference, SExtractor uses 8-connected pixels.
+        are grouped into a detected source. The options are 4 or
+        8 (default). 4-connected pixels touch along their edges.
+        8-connected pixels touch along their edges or corners. For
+        reference, SourceExtractor uses 8-connected pixels.
 
     mask : array_like of bool, optional
         A boolean mask, with the same shape as the input ``data``, where
@@ -281,7 +280,7 @@ def detect_sources(data, threshold, npixels, filter_kernel=None,
         shape = (100, 200)
         sources = make_gaussian_sources_image(shape, table)
         noise = make_noise_image(shape, distribution='gaussian', mean=0.,
-                                 stddev=5., random_state=12345)
+                                 stddev=5., seed=0)
         image = sources + noise
 
         # detect the sources
@@ -306,11 +305,9 @@ def detect_sources(data, threshold, npixels, filter_kernel=None,
                            connectivity=connectivity, mask=mask)[0]
 
 
-@deprecated_renamed_argument('snr', 'nsigma', 0.7)
-@deprecated_renamed_argument('mask_value', None, 0.7)
-def make_source_mask(data, nsigma, npixels, mask=None, mask_value=None,
-                     filter_fwhm=None, filter_size=3, filter_kernel=None,
-                     sigclip_sigma=3.0, sigclip_iters=5, dilate_size=11):
+def make_source_mask(data, nsigma, npixels, mask=None, filter_fwhm=None,
+                     filter_size=3, filter_kernel=None, sigclip_sigma=3.0,
+                     sigclip_iters=5, dilate_size=11):
     """
     Make a source mask using source segmentation and binary dilation.
 
@@ -335,12 +332,6 @@ def make_source_mask(data, nsigma, npixels, mask=None, mask_value=None,
         Masked pixels are ignored when computing the image background
         statistics.
 
-    mask_value : float, optional
-        Deprecated.
-        An image data value (e.g., ``0.0``) that is ignored when
-        computing the image background statistics.  ``mask_value`` will
-        be ignored if ``mask`` is input.
-
     filter_fwhm : float, optional
         The full-width at half-maximum (FWHM) of the Gaussian kernel to
         filter the image before thresholding.  ``filter_fwhm`` and
@@ -363,10 +354,10 @@ def make_source_mask(data, nsigma, npixels, mask=None, mask_value=None,
         when calculating the image background statistics.
 
     sigclip_iters : int, optional
-       The number of iterations to perform sigma clipping, or `None` to
-       clip until convergence is achieved (i.e., continue until the last
-       iteration clips nothing) when calculating the image background
-       statistics.
+       The maximum number of iterations to perform sigma clipping, or
+       `None` to clip until convergence is achieved (i.e., continue
+       until the last iteration clips nothing) when calculating the
+       image background statistics.
 
     dilate_size : int, optional
         The size of the square array used to dilate the segmentation
@@ -381,8 +372,7 @@ def make_source_mask(data, nsigma, npixels, mask=None, mask_value=None,
     from scipy import ndimage
 
     threshold = detect_threshold(data, nsigma, background=None, error=None,
-                                 mask=mask, mask_value=None,
-                                 sigclip_sigma=sigclip_sigma,
+                                 mask=mask, sigclip_sigma=sigclip_sigma,
                                  sigclip_iters=sigclip_iters)
 
     kernel = None
