@@ -4,19 +4,23 @@ This module provides tools for calculating the properties of sources
 defined by a segmentation image.
 """
 
+from copy import deepcopy
 import warnings
 
 from astropy.coordinates import SkyCoord
+from astropy.stats import SigmaClip
 from astropy.table import QTable
 import astropy.units as u
-from astropy.utils import deprecated, lazyproperty
+from astropy.utils import lazyproperty
 from astropy.utils.exceptions import AstropyUserWarning
 import numpy as np
 
 from .core import SegmentationImage
-from ..aperture import BoundingBox
+from ..background import SExtractorBackground
+from ..aperture import (BoundingBox, CircularAperture, EllipticalAperture,
+                        RectangularAnnulus)
+from ..utils._convolution import _filter_data
 from ..utils._moments import _moments, _moments_central
-from ..utils.convolution import _filter_data
 from ..utils._wcs_helpers import _pixel_to_world
 
 __all__ = ['SourceProperties', 'source_properties', 'SourceCatalog']
@@ -116,33 +120,67 @@ class SourceProperties:
         be masked using the ``mask`` keyword.
 
     wcs : WCS object or `None`, optional
-        A world coordinate system (WCS) transformation that supports the
-        `astropy shared interface for WCS
-        <https://docs.astropy.org/en/stable/wcs/wcsapi.html>`_ (e.g.
-        `astropy.wcs.WCS`, `gwcs.wcs.WCS`).  If `None`, then all sky-based
-        properties will be set to `None`.
+        A world coordinate system (WCS) transformation that
+        supports the `astropy shared interface for WCS
+        <https://docs.astropy.org/en/stable/wcs/wcsapi.html>`_ (e.g.,
+        `astropy.wcs.WCS`, `gwcs.wcs.WCS`). If `None`, then all
+        sky-based properties will be set to `None`.
+
+    localbkg_width : `None` or positive int, optional
+        The width of the rectangular annulus used to compute a local
+        background around each source. If `None` then no local
+        background subtraction is performed. The local background
+        affects the ``source_sum``, ``max_value``, ``min_value``, and
+        ``kron_flux`` properties. It does not affect the moment-based
+        morphological properties of the source.
+
+    kron_params : tuple of list, optional
+        A list of five parameters used to determine how the Kron radius
+        and flux are calculated. The first item represents how data
+        pixels are masked around the source. It must be one of:
+
+          * 'none':  do not mask any pixels (equivalent to
+                     MASK_TYPE=NONE in SourceExtractor).
+          * 'mask':  mask pixels assigned to neighboring sources
+                     (equivalent to MASK_TYPE=BLANK in SourceExtractor)
+          * 'mask_all':  mask all pixels outside of the source segment.
+          * 'correct':  replace pixels assigned to neighboring sources
+                        by replacing them with pixels on the opposite
+                        side of the source (equivalent to
+                        MASK_TYPE=CORRECT in SourceExtractor).
+
+        The second item represents the scaling parameter of the Kron
+        radius as a scalar float. The third item represents the minimum
+        circular radius as a scalar float. If the Kron radius times
+        sqrt(``semimajor_axis_sigma`` * ``semiminor_axis_sigma``) is
+        less than than this radius, then the Kron flux will be measured
+        in a circle with this minimum radius. The forth and fifth items
+        represent the :func:`~photutils.aperture.aperture_photometry`
+        keywords ``method`` and ``subpixels``, respectively, which are
+        used to measure the flux in the Kron aperture.
 
     Notes
     -----
     ``data`` (and optional ``filtered_data``) should be
     background-subtracted for accurate source photometry and properties.
 
-    `SExtractor`_'s centroid and morphological parameters are always
-    calculated from a filtered "detection" image, i.e. the image used to
-    define the segmentation image.  The usual downside of the filtering
-    is the sources will be made more circular than they actually are.
-    If you wish to reproduce `SExtractor`_ centroid and morphology
-    results, then input a filtered and background-subtracted "detection"
-    image into the ``filtered_data`` keyword.  If ``filtered_data`` is
-    `None`, then the unfiltered ``data`` will be used for the source
-    centroid and morphological parameters.
+    `SourceExtractor`_'s centroid and morphological parameters are
+    always calculated from a filtered "detection" image, i.e., the
+    image used to define the segmentation image. The usual downside
+    of the filtering is the sources will be made more circular than
+    they actually are. If you wish to reproduce `SourceExtractor`_
+    centroid and morphology results, then input a filtered and
+    background-subtracted "detection" image into the ``filtered_data``
+    keyword. If ``filtered_data`` is `None`, then the unfiltered
+    ``data`` will be used for the source centroid and morphological
+    parameters.
 
-    Negative data values (``filtered_data`` or ``data``) within the
-    source segment are set to zero when calculating morphological
-    properties based on image moments.  Negative values could occur, for
-    example, if the segmentation image was defined from a different
-    image (e.g., different bandpass) or if the background was
-    oversubtracted. Note that
+    Negative data values (``filtered_data`` or ``data``)
+    within the source segment are set to zero when calculating
+    morphological properties based on image moments. Negative
+    values could occur, for example, if the segmentation
+    image was defined from a different image (e.g., different
+    bandpass) or if the background was oversubtracted. Note that
     `~photutils.segmentation.SourceProperties.source_sum` always
     includes the contribution of negative ``data`` values.
 
@@ -168,11 +206,13 @@ class SourceProperties:
     pixels outside of the source segment, masked pixels from the
     ``mask`` input, or any non-finite ``data`` values (NaN and +/- inf).
 
-    .. _SExtractor: https://www.astromatic.net/software/sextractor
+    .. _SourceExtractor: https://sextractor.readthedocs.io/en/latest/
     """
 
     def __init__(self, data, segment_img, label, filtered_data=None,
-                 error=None, mask=None, background=None, wcs=None):
+                 error=None, mask=None, background=None, wcs=None,
+                 localbkg_width=None,
+                 kron_params=('mask', 2.5, 0.0, 'exact', 5)):
 
         if not isinstance(segment_img, SegmentationImage):
             segment_img = SegmentationImage(segment_img)
@@ -245,6 +285,15 @@ class SourceProperties:
         self.segment = segment_img[segment_img.get_index(label)]
         self.slices = self.segment.slices
 
+        if localbkg_width is not None and localbkg_width <= 0:
+            raise ValueError('localbkg_width must be >= 0')
+        self.localbkg_width = localbkg_width
+
+        if kron_params[0] not in ('none', 'mask', 'mask_all', 'correct'):
+            raise ValueError('Invalid value for kron_params[0]')
+        self.kron_params = kron_params
+        self._kron_fluxerr = None
+
     def __str__(self):
         cls_name = '<{0}.{1}>'.format(self.__class__.__module__,
                                       self.__class__.__name__)
@@ -376,9 +425,9 @@ class SourceProperties:
         minimal bounding box of the source segment.
 
         If ``masked_array`` is `False` (default), then the returned
-        cutout array is simply a `~numpy.ndarray`.  The returned cutout
-        is a view (not a copy) of the input ``data``.  No pixels are
-        altered (e.g. set to zero) within the bounding box.
+        cutout array is simply a `~numpy.ndarray`. The returned cutout
+        is a view (not a copy) of the input ``data``. No pixels are
+        altered (e.g., set to zero) within the bounding box.
 
         If ``masked_array` is `True`, then the returned cutout array is
         a `~numpy.ma.MaskedArray`.  The mask is `True` for pixels
@@ -527,21 +576,6 @@ class SourceProperties:
             return np.ma.masked_array(self._background[self.slices],
                                       mask=self._total_mask)
 
-    @lazyproperty
-    @deprecated('0.7')
-    def values(self):
-        """
-        A 1D `~numpy.ndarray` of the unmasked ``data`` values within the
-        source segment.
-
-        Non-finite pixel values (NaN and +/- inf) are excluded
-        (automatically masked).
-
-        If all pixels are masked, ``values`` will be an empty array.
-        """
-
-        return self._data_values  # pragma: no cover
-
     @lazyproperty
     def _data_values(self):
         """
@@ -588,22 +622,6 @@ class SourceProperties:
         return (yindices + self.slices[0].start,
                 xindices + self.slices[1].start)
 
-    @lazyproperty
-    @deprecated('0.7', 'indices')
-    def coords(self):
-        """
-        A tuple of two `~numpy.ndarray` containing the ``y`` and ``x``
-        pixel indices, respectively, of unmasked pixels within the
-        source segment.
-
-        Non-finite ``data`` values (NaN and +/- inf) are excluded.
-
-        If all ``data`` pixels are masked, a tuple of two empty arrays
-        will be returned.
-        """
-
-        return self.indices  # pragma: no cover
-
     @lazyproperty
     def moments(self):
         """Spatial moments up to 3rd order of the source."""
@@ -747,50 +765,6 @@ class SourceProperties:
 
         return (self.bbox.iymax - 1) * u.pix
 
-    @lazyproperty
-    @deprecated('0.7', 'bbox_xmin')
-    def xmin(self):
-        """
-        The minimum ``x`` pixel location within the minimal bounding box
-        containing the source segment.
-        """
-
-        return self.bbox_xmin  # pragma: no cover
-
-    @lazyproperty
-    @deprecated('0.7', 'bbox_xmax')
-    def xmax(self):
-        """
-        The maximum ``x`` pixel location within the minimal bounding box
-        containing the source segment.
-
-        Note that this value is inclusive, unlike numpy slice indices.
-        """
-
-        return self.bbox_xmax  # pragma: no cover
-
-    @lazyproperty
-    @deprecated('0.7', 'bbox_ymin')
-    def ymin(self):
-        """
-        The minimum ``y`` pixel location within the minimal bounding box
-        containing the source segment.
-        """
-
-        return self.bbox_ymin  # pragma: no cover
-
-    @lazyproperty
-    @deprecated('0.7', 'bbox_ymax')
-    def ymax(self):
-        """
-        The maximum``y`` pixel location within the minimal bounding box
-        containing the source segment.
-
-        Note that this value is inclusive, unlike numpy slice indices.
-        """
-
-        return self.bbox_ymax  # pragma: no cover
-
     @lazyproperty
     def sky_bbox_ll(self):
         """
@@ -853,7 +827,7 @@ class SourceProperties:
         if self._is_completely_masked:
             return np.nan * self._data_unit
         else:
-            return np.min(self._data_values)
+            return np.min(self._data_values - self.local_background)
 
     @lazyproperty
     def max_value(self):
@@ -865,7 +839,7 @@ class SourceProperties:
         if self._is_completely_masked:
             return np.nan * self._data_unit
         else:
-            return np.max(self._data_values)
+            return np.max(self._data_values - self.local_background)
 
     @lazyproperty
     def minval_cutout_pos(self):
@@ -1005,7 +979,8 @@ class SourceProperties:
         if self._is_completely_masked:
             return np.nan * self._data_unit  # table output needs unit
         else:
-            return np.sum(self._data_values)
+            return (np.sum(self._data_values) -
+                    self.local_background * self.area.value)
 
     @lazyproperty
     def source_sum_err(self):
@@ -1134,7 +1109,7 @@ class SourceProperties:
         defined by a 4-pixel connectivity.
 
         If any masked pixels make holes within the source segment, then
-        the perimeter around the inner hole (e.g. an annulus) will also
+        the perimeter around the inner hole (e.g., an annulus) will also
         contribute to the total perimeter.
 
         References
@@ -1204,12 +1179,12 @@ class SourceProperties:
     def _check_covariance(covariance):
         """
         Check and modify the covariance matrix in the case of
-        "infinitely" thin detections.  This follows SExtractor's
+        "infinitely" thin detections.  This follows SourceExtractor's
         prescription of incrementally increasing the diagonal elements
         by 1/12.
         """
 
-        increment = 1. / 12  # arbitrary SExtractor value
+        increment = 1. / 12  # arbitrary SourceExtractor value
         value = (covariance[0, 0] * covariance[1, 1]) - covariance[0, 1]**2
         if value >= increment**2:
             return covariance
@@ -1245,7 +1220,7 @@ class SourceProperties:
         moments as the source.
         """
 
-        # this matches SExtractor's A parameter
+        # this matches SourceExtractor's A parameter
         return np.sqrt(self.covariance_eigvals[0])
 
     @lazyproperty
@@ -1256,7 +1231,7 @@ class SourceProperties:
         moments as the source.
         """
 
-        # this matches SExtractor's B parameter
+        # this matches SourceExtractor's B parameter
         return np.sqrt(self.covariance_eigvals[1])
 
     @lazyproperty
@@ -1282,10 +1257,9 @@ class SourceProperties:
     @lazyproperty
     def orientation(self):
         """
-        The angle in radians between the ``x`` axis and the major axis
-        of the 2D Gaussian function that has the same second-order
-        moments as the source.  The angle increases in the
-        counter-clockwise direction.
+        The angle between the ``x`` axis and the major axis of the 2D
+        Gaussian function that has the same second-order moments as the
+        source.  The angle increases in the counter-clockwise direction.
         """
 
         covar_00, covar_01, _, covar_11 = self.covariance.flat
@@ -1307,7 +1281,7 @@ class SourceProperties:
         where :math:`a` and :math:`b` are the lengths of the semimajor
         and semiminor axes, respectively.
 
-        Note that this is the same as `SExtractor`_'s elongation
+        Note that this is the same as `SourceExtractor`_'s elongation
         parameter.
         """
 
@@ -1324,7 +1298,7 @@ class SourceProperties:
         where :math:`a` and :math:`b` are the lengths of the semimajor
         and semiminor axes, respectively.
 
-        Note that this is the same as `SExtractor`_'s ellipticity
+        Note that this is the same as `SourceExtractor`_'s ellipticity
         parameter.
         """
 
@@ -1336,7 +1310,7 @@ class SourceProperties:
         The ``(0, 0)`` element of the `covariance` matrix, representing
         :math:`\\sigma_x^2`, in units of pixel**2.
 
-        Note that this is the same as `SExtractor`_'s X2 parameter.
+        Note that this is the same as `SourceExtractor`_'s X2 parameter.
         """
 
         return self.covariance[0, 0]
@@ -1347,7 +1321,7 @@ class SourceProperties:
         The ``(1, 1)`` element of the `covariance` matrix, representing
         :math:`\\sigma_y^2`, in units of pixel**2.
 
-        Note that this is the same as `SExtractor`_'s Y2 parameter.
+        Note that this is the same as `SourceExtractor`_'s Y2 parameter.
         """
 
         return self.covariance[1, 1]
@@ -1359,7 +1333,7 @@ class SourceProperties:
         matrix, representing :math:`\\sigma_x \\sigma_y`, in units of
         pixel**2.
 
-        Note that this is the same as `SExtractor`_'s XY parameter.
+        Note that this is the same as `SourceExtractor`_'s XY parameter.
         """
 
         return self.covariance[0, 1]
@@ -1367,7 +1341,8 @@ class SourceProperties:
     @lazyproperty
     def cxx(self):
         """
-        `SExtractor`_'s CXX ellipse parameter in units of pixel**(-2).
+        `SourceExtractor`_'s CXX ellipse parameter in units of
+        pixel**(-2).
 
         The ellipse is defined as
 
@@ -1376,7 +1351,7 @@ class SourceProperties:
                 cyy (y - \\bar{y})^2 = R^2
 
         where :math:`R` is a parameter which scales the ellipse (in
-        units of the axes lengths).  `SExtractor`_ reports that the
+        units of the axes lengths). `SourceExtractor`_ reports that the
         isophotal limit of a source is well represented by :math:`R
         \\approx 3`.
         """
@@ -1387,7 +1362,8 @@ class SourceProperties:
     @lazyproperty
     def cyy(self):
         """
-        `SExtractor`_'s CYY ellipse parameter in units of pixel**(-2).
+        `SourceExtractor`_'s CYY ellipse parameter in units of
+        pixel**(-2).
 
         The ellipse is defined as
 
@@ -1396,7 +1372,7 @@ class SourceProperties:
                 cyy (y - \\bar{y})^2 = R^2
 
         where :math:`R` is a parameter which scales the ellipse (in
-        units of the axes lengths).  `SExtractor`_ reports that the
+        units of the axes lengths). `SourceExtractor`_ reports that the
         isophotal limit of a source is well represented by :math:`R
         \\approx 3`.
         """
@@ -1407,7 +1383,8 @@ class SourceProperties:
     @lazyproperty
     def cxy(self):
         """
-        `SExtractor`_'s CXY ellipse parameter in units of pixel**(-2).
+        `SourceExtractor`_'s CXY ellipse parameter in units of
+        pixel**(-2).
 
         The ellipse is defined as
 
@@ -1416,7 +1393,7 @@ class SourceProperties:
                 cyy (y - \\bar{y})^2 = R^2
 
         where :math:`R` is a parameter which scales the ellipse (in
-        units of the axes lengths).  `SExtractor`_ reports that the
+        units of the axes lengths). `SourceExtractor`_ reports that the
         isophotal limit of a source is well represented by :math:`R
         \\approx 3`.
         """
@@ -1425,6 +1402,261 @@ class SourceProperties:
                 ((1. / self.semimajor_axis_sigma**2) -
                  (1. / self.semiminor_axis_sigma**2)))
 
+    @lazyproperty
+    def local_background_aperture(self):
+        """
+        The rectangular annulus aperture used to estimate the local
+        background.
+        """
+        if self.localbkg_width is None:
+            return None
+
+        xpos = 0.5 * (self.bbox.ixmin + self.bbox.ixmax - 1)
+        ypos = 0.5 * (self.bbox.iymin + self.bbox.iymax - 1)
+        scale = 1.5
+        width_bbox = self.bbox.ixmax - self.bbox.ixmin
+        width_in = width_bbox * scale
+        width_out = width_in + 2 * self.localbkg_width
+        height_bbox = self.bbox.iymax - self.bbox.iymin
+        height_in = height_bbox * scale
+        height_out = height_in + 2 * self.localbkg_width
+
+        return RectangularAnnulus((xpos, ypos), width_in, width_out,
+                                  height_out, height_in, theta=0.)
+
+    @lazyproperty
+    def local_background(self):
+        """
+        The local background value estimated using a rectangular annulus
+        aperture around the source.
+        """
+        if self.localbkg_width is None:
+            return 0.
+
+        aperture = self.local_background_aperture
+        aperture_mask = aperture.to_mask(method='center')
+
+        mask = ~np.isfinite(self._data)
+        if self._mask is not None:
+            mask |= self._mask
+
+        data = aperture_mask.cutout(self._data, copy=True)
+        mask = aperture_mask.cutout(mask)
+        segm_mask = self._mask_neighbors(aperture_mask, method='mask')
+
+        # need to define new aperture mask
+        aperture = deepcopy(self.local_background_aperture)
+        aperture.positions -= (aperture_mask.bbox.ixmin,
+                               aperture_mask.bbox.iymin)
+        aperture_mask = aperture.to_mask(method='center')
+
+        mask |= aperture_mask._mask
+        if segm_mask is not None:
+            mask |= segm_mask
+        pix1d = aperture_mask.multiply(data)[~mask]
+        if len(pix1d) < 10:  # not enough unmasked pixels
+            return 0.
+        sigma_clip = SigmaClip(sigma=3.0, cenfunc='median', maxiters=20)
+        bkg_func = SExtractorBackground(sigma_clip)
+        if isinstance(pix1d, u.Quantity):
+            return bkg_func(pix1d.value) * self._data_unit
+        return bkg_func(pix1d)
+
+    def _elliptical_aperture(self, radius=6.):
+        """
+        Parameters
+        ----------
+        radius : float, optional
+            The elliptical "radius". The default value of 6.0 is roughly
+            two times the isophotal extent of the source.
+        """
+        position = (self.xcentroid.value, self.ycentroid.value)
+        a = self.semimajor_axis_sigma.value * radius
+        b = self.semiminor_axis_sigma.value * radius
+        theta = self.orientation.to(u.radian).value
+        return EllipticalAperture(position, a, b, theta=theta)
+
+    def _mask_neighbors(self, aperture_mask, method='none'):
+        if method == 'none':
+            return None
+
+        segment_img = aperture_mask.cutout(self._segment_img.data,
+                                           copy=True)
+
+        # mask all pixels outside of the source segment
+        if method in ('mask_all', ):
+            segm_mask = (segment_img != self.id)
+
+        # mask pixels *only* in neighboring segments (not including
+        # background pixels)
+        if method in ('mask', 'correct'):
+            segm_mask = np.logical_and(segment_img != self.id,
+                                       segment_img != 0)
+
+        return segm_mask
+
+    def _prepare_kron_data(self, aperture_mask):
+        mask = ~np.isfinite(self._data)
+        if self._mask is not None:
+            mask |= self._mask
+
+        data = aperture_mask.cutout(self._data, copy=True)
+        mask = aperture_mask.cutout(mask)
+        data[mask] = 0.
+
+        segm_mask = self._mask_neighbors(aperture_mask,
+                                         method=self.kron_params[0])
+        if segm_mask is not None:
+            data[segm_mask] = 0.
+
+        if self._error is not None:
+            error = aperture_mask.cutout(self._error, copy=True)
+            if segm_mask is not None:
+                error[segm_mask] = 0.
+        else:
+            error = None
+
+        # Correct masked pixels in neighboring segments.  Masked pixels
+        # are replaced with pixels on the opposite side of the source.
+        if self.kron_params[0] == 'correct':
+            from ..utils.interpolation import _mask_to_mirrored_num
+            xypos = (self.xcentroid.value, self.ycentroid.value)
+            data = _mask_to_mirrored_num(data, segm_mask, xypos)
+            if self._error is not None:
+                error = _mask_to_mirrored_num(error, segm_mask, xypos)
+
+        return data, error
+
+    @lazyproperty
+    def kron_radius(self):
+        """
+        The unscaled first-moment Kron radius.
+
+        The unscaled first-moment Kron radius is given by:
+
+        .. math::
+            k_r = \\frac{\\sum_{i \\in A} \\ r_i I_i}{\\sum_{i \\in A} I_i}
+
+        where the sum is over all pixels in an elliptical aperture whose
+        axes are defined by six times the ``semimajor_axis_sigma`` and
+        ``semiminor_axis_sigma`` at the calculated ``orientation``
+        (all properties derived from the central image moments of the
+        source). :math:`r_i` is the elliptical "radius" to the pixel
+        given by:
+
+        .. math::
+            r_i^2 = cxx(x_i - \\bar{x})^2 +
+                cxx \\ cyy (x_i - \\bar{x})(y_i - \\bar{y}) +
+                cyy(y_i - \\bar{y})^2
+
+        where :math:`\\bar{x}` and :math:`\\bar{y}` represent the source
+        centroid.
+
+        If either the numerator or denominator <= 0, then ``np.nan``
+        will be returned. In this case, the Kron aperture will
+        be defined as a circular aperture with a radius equal to
+        ``kron_params[2]``. If ``kron_params[2] <= 0``, then the Kron
+        aperture will be `None` and the Kron flux will be ``np.nan``.
+        """
+        aperture = self._elliptical_aperture(radius=6.0)
+        aperture_mask = aperture.to_mask()
+
+        # prepare cutouts of the data and error arrays based on the
+        # aperture size
+        data, error = self._prepare_kron_data(aperture_mask)
+        aperture.positions -= (aperture_mask.bbox.ixmin,
+                               aperture_mask.bbox.iymin)
+
+        x = (np.arange(data.shape[1]) - self.xcentroid.value +
+             aperture_mask.bbox.ixmin)
+        y = (np.arange(data.shape[0]) - self.ycentroid.value +
+             aperture_mask.bbox.iymin)
+        xx, yy = np.meshgrid(x, y)
+        rr = np.sqrt(self.cxx.value * xx**2 + self.cxy.value * xx * yy
+                     + self.cyy.value * yy**2)
+
+        method = 'center'  # need whole pixel to compute Kron radius
+        if isinstance(data, u.Quantity):
+            data = data.value
+        flux_numer, _ = aperture.do_photometry(data * rr, method=method)
+        flux_denom, _ = aperture.do_photometry(data, method=method)
+
+        if flux_numer <= 0 or flux_denom <= 0:
+            return np.nan << u.pixel
+        return (flux_numer[0] / flux_denom[0]) << u.pixel
+
+    @lazyproperty
+    def kron_aperture(self):
+        """
+        The Kron aperture.
+
+        If ``kron_radius = np.nan`` or ``kron_radius *
+        np.sqrt(semimajor_axis_sigma * semiminor_axis_sigma) <
+        kron_params[2]`` then a circular aperture with a radius equal to
+        ``kron_params[2]`` will be returned. If ``kron_params[2] <= 0``,
+        then the Kron aperture will be `None`, and the Kron flux will be
+        ``np.nan``.
+        """
+        a = self.semimajor_axis_sigma.value
+        b = self.semiminor_axis_sigma.value
+        circ_radius = self.kron_radius.value * np.sqrt(a * b)
+        min_radius = self.kron_params[2]
+        if np.isnan(self.kron_radius.value) or circ_radius < min_radius:
+            if min_radius <= 0:
+                return None
+            # use circular aperture with radius=self.kron_params[2]
+            xypos = (self.xcentroid.value, self.ycentroid.value)
+            aperture = CircularAperture(xypos, r=self.kron_params[2])
+        else:
+            radius = self.kron_radius.value * self.kron_params[1]
+            aperture = self._elliptical_aperture(radius=radius)
+
+        return aperture
+
+    @lazyproperty
+    def kron_flux(self):
+        """
+        The flux in the Kron aperture.
+
+        If the Kron aperture is `None`, then ``np.nan`` will be returned.
+        """
+        if self.kron_aperture is None:
+            self._kron_fluxerr = np.nan * self._data_unit
+            return np.nan * self._data_unit
+
+        aperture = deepcopy(self.kron_aperture)
+        aperture_mask = aperture.to_mask()
+        data, error = self._prepare_kron_data(aperture_mask)
+        aperture.positions -= (aperture_mask.bbox.ixmin,
+                               aperture_mask.bbox.iymin)
+
+        method = self.kron_params[3]
+        subpixels = self.kron_params[4]
+        flux, fluxerr = aperture.do_photometry(data - self.local_background,
+                                               error=error, method=method,
+                                               subpixels=subpixels)
+        if len(fluxerr) > 0:
+            self._kron_fluxerr = fluxerr[0]
+        else:
+            self._kron_fluxerr = None
+
+        return flux[0]
+
+    @lazyproperty
+    def kron_fluxerr(self):
+        """
+        The flux error in the Kron aperture.
+
+        If the Kron aperture is `None`, then ``np.nan`` will be returned.
+        """
+        if self._kron_fluxerr is None:
+            _ = self.kron_flux  # run kron_flux to computer kron_fluxerr
+
+        if self._error is None:
+            return None
+
+        return self._kron_fluxerr
+
     @lazyproperty
     def gini(self):
         """
@@ -1434,7 +1666,8 @@ class SourceProperties:
 
         The Gini coefficient is calculated using the prescription from
         `Lotz et al. 2004
-        <http://adsabs.harvard.edu/abs/2004AJ....128..163L>`_ as:
+        <https://ui.adsabs.harvard.edu/abs/2004AJ....128..163L/abstract>`_
+        as:
 
         .. math::
             G = \\frac{1}{\\left | \\bar{x} \\right | n (n - 1)}
@@ -1463,7 +1696,8 @@ class SourceProperties:
 
 def source_properties(data, segment_img, error=None, mask=None,
                       background=None, filter_kernel=None, wcs=None,
-                      labels=None):
+                      labels=None, localbkg_width=None,
+                      kron_params=('mask', 2.5, 0.0, 'exact', 5)):
     """
     Calculate photometry and morphological properties of sources defined
     by a labeled segmentation image.
@@ -1516,15 +1750,15 @@ def source_properties(data, segment_img, error=None, mask=None,
     filter_kernel : array-like (2D) or `~astropy.convolution.Kernel2D`, optional
         The 2D array of the kernel used to filter the data prior to
         calculating the source centroid and morphological parameters.
-        The kernel should be the same one used in defining the source
-        segments, i.e. the detection image (e.g., see
-        :func:`~photutils.segmentation.detect_sources`).  If `None`,
-        then the unfiltered ``data`` will be used instead.
+        The kernel should be the same one used in defining the
+        source segments, i.e., the detection image (e.g., see
+        :func:`~photutils.segmentation.detect_sources`). If `None`, then
+        the unfiltered ``data`` will be used instead.
 
     wcs : `None` or WCS object, optional
         A world coordinate system (WCS) transformation that supports the
         `astropy shared interface for WCS
-        <https://docs.astropy.org/en/stable/wcs/wcsapi.html>`_ (e.g.
+        <https://docs.astropy.org/en/stable/wcs/wcsapi.html>`_ (e.g.,
         `astropy.wcs.WCS`, `gwcs.wcs.WCS`).  If `None`, then all sky-based
         properties will be set to `None`.
 
@@ -1533,6 +1767,39 @@ def source_properties(data, segment_img, error=None, mask=None,
         properties.  If `None` (default), then the properties will be
         calculated for all labeled sources.
 
+    localbkg_width : `None` or positive int, optional
+        The width of the rectangular annulus used to compute a local
+        background around each source. If `None` then no local
+        background subtraction is performed. The local background
+        affects the ``source_sum``, ``max_value``, ``min_value``, and
+        ``kron_flux`` properties. It does not affect the moment-based
+        morphological properties of the source.
+
+    kron_params : tuple of list, optional
+        A list of five parameters used to determine how the Kron radius
+        and flux are calculated. The first item represents how data
+        pixels are masked around the source. It must be one of:
+
+          * 'none':  do not mask any pixels (equivalent to
+                     MASK_TYPE=NONE in SourceExtractor).
+          * 'mask':  mask pixels assigned to neighboring sources
+                     (equivalent to MASK_TYPE=BLANK in SourceExtractor)
+          * 'mask_all':  mask all pixels outside of the source segment.
+          * 'correct':  replace pixels assigned to neighboring sources
+                        by replacing them with pixels on the opposite
+                        side of the source (equivalent to
+                        MASK_TYPE=CORRECT in SourceExtractor).
+
+        The second item represents the scaling parameter of the Kron
+        radius as a scalar float. The third item represents the minimum
+        circular radius as a scalar float. If the Kron radius times
+        sqrt(``semimajor_axis_sigma`` * ``semiminor_axis_sigma``) is
+        less than than this radius, then the Kron flux will be measured
+        in a circle with this minimum radius. The forth and fifth items
+        represent the :func:`~photutils.aperture.aperture_photometry`
+        keywords ``method`` and ``subpixels``, respectively, which are
+        used to measure the flux in the Kron aperture.
+
     Returns
     -------
     output : `SourceCatalog` instance
@@ -1541,15 +1808,16 @@ def source_properties(data, segment_img, error=None, mask=None,
 
     Notes
     -----
-    `SExtractor`_'s centroid and morphological parameters are always
-    calculated from a filtered "detection" image, i.e. the image used to
-    define the segmentation image.  The usual downside of the filtering
-    is the sources will be made more circular than they actually are.
-    If you wish to reproduce `SExtractor`_ centroid and morphology
-    results, then input a filtered and background-subtracted "detection"
-    image into the ``filtered_data`` keyword.  If ``filtered_data`` is
-    `None`, then the unfiltered ``data`` will be used for the source
-    centroid and morphological parameters.
+    `SourceExtractor`_'s centroid and morphological parameters are
+    always calculated from a filtered "detection" image, i.e., the
+    image used to define the segmentation image. The usual downside
+    of the filtering is the sources will be made more circular than
+    they actually are. If you wish to reproduce `SourceExtractor`_
+    centroid and morphology results, then input a filtered and
+    background-subtracted "detection" image into the ``filtered_data``
+    keyword. If ``filtered_data`` is `None`, then the unfiltered
+    ``data`` will be used for the source centroid and morphological
+    parameters.
 
     Negative data values (``filtered_data`` or ``data``) within the
     source segment are set to zero when calculating morphological
@@ -1574,7 +1842,7 @@ def source_properties(data, segment_img, error=None, mask=None,
     are the non-masked pixels in the source segment, and
     :math:`\\sigma_{\\mathrm{tot}, i}` is the input ``error`` array.
 
-    .. _SExtractor: https://www.astromatic.net/software/sextractor
+    .. _SourceExtractor: https://sextractor.readthedocs.io/en/latest/
 
     See Also
     --------
@@ -1649,7 +1917,8 @@ def source_properties(data, segment_img, error=None, mask=None,
 
         sources_props.append(SourceProperties(
             data, segment_img, label, filtered_data=filtered_data,
-            error=error, mask=mask, background=background, wcs=wcs))
+            error=error, mask=mask, background=background, wcs=wcs,
+            localbkg_width=localbkg_width, kron_params=kron_params))
 
     if not sources_props:
         raise ValueError('No sources are defined.')
@@ -1752,7 +2021,8 @@ class SourceCatalog:
             # SkyCoord array from a loop-generated SkyCoord list.  The
             # assumption here is that the wcs is the same for each
             # SourceProperties instance.
-            return _pixel_to_world(self.xcentroid, self.ycentroid, self.wcs)
+            return _pixel_to_world(self.xcentroid.value, self.ycentroid.value,
+                                   self.wcs)
 
     @lazyproperty
     def sky_centroid_icrs(self):
@@ -1798,11 +2068,11 @@ class SourceCatalog:
         `~astropy.table.QTable` will include a default list of
         scalar-valued properties.
 
-        Multi-dimensional properties, e.g.
-        `~photutils.segmentation.SourceProperties.data_cutout`, can be
-        included in the ``columns`` input, but they will not be
-        preserved when writing the table to a file.  This is a
-        limitation of multi-dimensional columns in astropy tables.
+        Multi-dimensional properties, e.g.,
+        `~photutils.segmentation.SourceProperties.data_cutout`, can
+        be included in the ``columns`` input, but they will not be
+        preserved when writing the table to a file. This is a limitation
+        of multi-dimensional columns in astropy tables.
 
         Parameters
         ----------
@@ -1938,9 +2208,9 @@ def _calc_sky_bbox_corner(bbox, corner, wcs):
             * 'ur':  upper right
 
     wcs : `None` or WCS object
-        A world coordinate system (WCS) transformation that supports the
-        `astropy shared interface for WCS
-        <https://docs.astropy.org/en/stable/wcs/wcsapi.html>`_ (e.g.
+        A world coordinate system (WCS) transformation that
+        supports the `astropy shared interface for WCS
+        <https://docs.astropy.org/en/stable/wcs/wcsapi.html>`_ (e.g.,
         `astropy.wcs.WCS`, `gwcs.wcs.WCS`).
 
     Returns
