@@ -3,13 +3,11 @@
 This module provides tools for interpolating data.
 """
 
-from astropy.utils import deprecated
 import numpy as np
 
-__all__ = ['ShepardIDWInterpolator', 'mask_to_mirrored_num']
+__all__ = ['ShepardIDWInterpolator']
 
 __doctest_requires__ = {('ShepardIDWInterpolator'): ['scipy']}
-__doctest_skip__ = ['mask_to_mirrored_num']
 
 
 class ShepardIDWInterpolator:
@@ -86,33 +84,34 @@ class ShepardIDWInterpolator:
     Example of interpolating 1D data::
 
         >>> import numpy as np
-        >>> np.random.seed(123)
-        >>> x = np.random.random(100)
+        >>> rng = np.random.default_rng(0)
+        >>> x = rng.random(100)  # 100 random values
         >>> y = np.sin(x)
         >>> f = idw(x, y)
         >>> f(0.4)  # doctest: +FLOAT_CMP
-        0.38862424043228855
+        0.38937843420912366
         >>> np.sin(0.4)  # doctest: +FLOAT_CMP
         0.3894183423086505
 
-        >>> xi = np.random.random(4)
+        >>> xi = rng.random(4)  # 4 random values
         >>> xi  # doctest: +FLOAT_CMP
-        array([0.51312815, 0.66662455, 0.10590849, 0.13089495])
+        array([0.47998792, 0.23237292, 0.80188058, 0.92353016])
         >>> f(xi)  # doctest: +FLOAT_CMP
-        array([0.49086423, 0.62647862, 0.1056854 , 0.13048335])
+        array([0.46577097, 0.22837422, 0.71856662, 0.80125391])
         >>> np.sin(xi)  # doctest: +FLOAT_CMP
-        array([0.49090493, 0.6183367 , 0.10571061, 0.13052149])
+        array([0.46176846, 0.23028731, 0.71866503, 0.7977353 ])
 
     NOTE: In the last example, ``xi`` may be a ``Nx1`` array instead of
     a 1D vector.
 
     Example of interpolating 2D data::
 
-        >>> pos = np.random.rand(1000, 2)
+        >>> rng = np.random.default_rng(0)
+        >>> pos = rng.random((1000, 2))
         >>> val = np.sin(pos[:, 0] + pos[:, 1])
         >>> f = idw(pos, val)
         >>> f([0.5, 0.6])  # doctest: +FLOAT_CMP
-        0.8931264958740567
+        0.8948257014687874
         >>> np.sin(0.5 + 0.6)  # doctest: +FLOAT_CMP
         0.8912073600614354
     """
@@ -206,7 +205,7 @@ class ShepardIDWInterpolator:
             singularities at the known data points, especially if
             ``reg`` is 0.0.
 
-        dtype : data-type
+        dtype : data-type, optional
             The data type of the output interpolated values. If `None`
             then the type will be inferred from the type of the
             ``values`` parameter used during the initialization of the
@@ -287,7 +286,7 @@ class ShepardIDWInterpolator:
 def _mask_to_mirrored_num(image, mask_image, center_position, bbox=None):
     """
     Replace masked pixels with the value of the pixel mirrored across a
-    given ``center_position``.  If the mirror pixel is unavailable (i.e.
+    given ``center_position``. If the mirror pixel is unavailable (i.e.,
     itself masked or outside of the image), then the masked pixel value
     is set to zero.
 
@@ -348,53 +347,3 @@ def _mask_to_mirrored_num(image, mask_image, center_position, bbox=None):
     outimage[bbox[2]:bbox[3]+1, bbox[0]:bbox[1]+1] = subdata
 
     return outimage
-
-
-@deprecated(0.7)
-def mask_to_mirrored_num(image, mask_image, center_position, bbox=None):
-    """
-    Replace masked pixels with the value of the pixel mirrored across a
-    given ``center_position``.  If the mirror pixel is unavailable (i.e.
-    itself masked or outside of the image), then the masked pixel value
-    is set to zero.
-
-    Parameters
-    ----------
-    image : `numpy.ndarray`, 2D
-        The 2D array of the image.
-
-    mask_image : array-like, bool
-        A boolean mask with the same shape as ``image``, where a `True`
-        value indicates the corresponding element of ``image`` is
-        considered bad.
-
-    center_position : 2-tuple
-        (x, y) center coordinates around which masked pixels will be
-        mirrored.
-
-    bbox : list, tuple, `numpy.ndarray`, optional
-        The bounding box (x_min, x_max, y_min, y_max) over which to
-        replace masked pixels.
-
-    Returns
-    -------
-    result : `numpy.ndarray`, 2D
-        A 2D array with replaced masked pixels.
-
-    Examples
-    --------
-    >>> import numpy as np
-    >>> from photutils.utils import mask_to_mirrored_num
-    >>> image = np.arange(16).reshape(4, 4)
-    >>> mask = np.zeros(image.shape, dtype=bool)
-    >>> mask[0, 0] = True
-    >>> mask[1, 1] = True
-    >>> mask_to_mirrored_num(image, mask, (1.5, 1.5))
-    array([[15,  1,  2,  3],
-           [ 4, 10,  6,  7],
-           [ 8,  9, 10, 11],
-           [12, 13, 14, 15]])
-    """
-
-    return _mask_to_mirrored_num(image, mask_image, center_position,
-                                 bbox=bbox)
